OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "نشانک‌ها",
    "You bookmarked \"%s\"" : "شما «%s» را نشانک کردید",
    "%1$s bookmarked \"%2$s\"" : "%1$s «%2$s» را نشانک کرد",
    "Someone bookmarked \"%s\"" : "شخصی «%s» را نشانک کرد",
    "You deleted \"%s\"" : "شما «%s» را حذف کردید",
    "%1$s deleted \"%2$s\"" : "%1$s «%2$s» را حذف کرد",
    "Someone deleted \"%s\"" : "شخصی «%s» را حذف کرد",
    "You created folder \"%s\"" : "شما پوشه «%s» را ایجاد کردید",
    "%1$s created folder \"%2$s\"" : "%1$s پوشه «%2$s» را ایجاد کرد",
    "Someone created folder \"%s\"" : "شخصی پوشه «%s» را ایجاد کرد",
    "You moved folder \"%s\"" : "شما پوشه «%s» را جابجا کردید",
    "%1$s moved folder \"%2$s\"" : "%1$s پوشه «%2$s» را جابجا کرد",
    "Someone moved folder \"%s\"" : "شخصی پوشه «%s» را جابجا کرد",
    "You deleted folder \"%s\"" : "شما پوشه «%s» را حذف کردید",
    "%1$s deleted folder \"%2$s\"" : "%1$s پوشه «%2$s» را حذف کرد",
    "Someone deleted folder \"%s\"" : "شخصی پوشه «%s» را حذف کرد",
    "You shared folder \"%1$s\" with %2$s" : "شما پوشه «%1$s» را با %2$s به اشتراک گذاشتید",
    "You shared folder \"%s\" with someone" : "شما پوشه «%s» را با شخصی به اشتراک گذاشتید",
    "%1$s shared folder \"%2$s\" with you" : "%1$s پوشه «%2$s» را با شما به اشتراک گذاشت",
    "Someone shared folder \"%s\" with you" : "شخصی پوشه «%s» را با شما به اشتراک گذاشت",
    "You unshared folder \"%1$s\" with %2$s" : "شما اشتراک‌گذاری پوشه «%1$s» را با %2$s لغو کردید",
    "You unshared folder \"%s\" with someone" : "شما اشتراک‌گذاری پوشه «%s» را با شخصی لغو کردید",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s اشتراک‌گذاری پوشه «%2$s» را با شما لغو کرد",
    "Someone unshared folder \"%s\" with you" : "شخصی اشتراک‌گذاری پوشه «%s» را با شما لغو کرد",
    "No file provided for import" : "فایلی برای وارد کردن ارائه نشده است",
    "Failed to upload file" : "بارگذاری فایل ناموفق بود",
    "Unsupported file type for import: " : "نوع فایل پشتیبانی‌نشده برای وارد کردن:",
    "Bookmarks shared by %s" : "نشانک‌های به اشتراک‌گذاشته‌شده توسط %s",
    "Frequent bookmarks" : "نشانک‌های پرکاربرد",
    "Recent bookmarks" : "نشانک‌های اخیر",
    "Bookmark" : "نشانک",
    "Bookmark deleted" : "نشانک حذف شد",
    "Bookmark created" : "نشانک ایجاد شد",
    "Bookmark moved" : "نشانک جابجا شد",
    "Bookmark updated" : "نشانک به‌روزرسانی شد",
    "Create bookmark" : "ایجاد نشانک",
    "Takes a link and adds it to your collection of bookmarks." : "یک پیوند دریافت کرده و آن را به مجموعه نشانک‌های خود اضافه می‌کند.",
    "Bookmarks Backups" : "پشتیبان‌گیری نشانک‌ها",
    "Collect and manage bookmarks, synced with all your devices" : "نشانک‌ها را جمع‌آوری و مدیریت کنید، همگام‌سازی با تمام دستگاه‌های شما",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 نشانک‌ها را در پوشه‌ها مرتب کنید\n- 🏷 برچسب و یادداشت شخصی اضافه کنید\n- ☠ پیوندهای خراب و تکراری را پیدا کنید\n- 📲 با همه مرورگرها و دستگاه‌هایتان همگام‌سازی کنید\n- 📔 نسخه‌های بایگانی‌شده پیوندهایتان را ذخیره کنید تا اگر حذف شدند، باز هم در دسترس باشند\n- 🔍 جستجوی تمام‌متن در محتوای سایت‌ها\n- 👪 نشانک‌ها را با کاربران، گروه‌ها و تیم‌های دیگر یا از طریق پیوندهای عمومی به اشتراک بگذارید\n- ⚛ خوراک RSS از مجموعه‌هایتان بسازید\n- 📈 آمار اینکه هر پیوند را چند بار باز می‌کنید\n- 🔒 پشتیبان‌گیری خودکار از مجموعه نشانک‌هایتان\n- 💼 ابزارک‌های داخلی داشبورد برای پیوندهای پربازدید و اخیر\n\nنیازمندی‌ها:\n - افزونه‌های PHP:\n   - intl: *\n   - mbstring: *\n - هنگام استفاده از MySQL، حداقل از نسخه v8.0 استفاده کنید",
    "Do you really want to delete this bookmark?" : "آیا واقعاً می‌خواهید این نشانک را حذف کنید؟",
    "Link copied to clipboard" : "پیوند در کلیپ‌بورد کپی شد",
    "Enter new title" : "عنوان جدید را وارد کنید",
    "Select bookmark" : "نشانک را انتخاب کنید",
    "You have never clicked this link" : "شما هرگز روی این پیوند کلیک نکرده‌اید",
    "You have clicked this link {count} times" : "شما {count} بار روی این پیوند کلیک کرده‌اید",
    "Details" : "جزئیات",
    "Rename" : "تغییر نام",
    "Copy link" : "کپی پیوند",
    "Move" : "جابجایی",
    "Add to folders" : "افزودن به پوشه‌ها",
    "Put bookmark into trash bin" : "انتقال بوکمارک به سطل زباله",
    "Restore bookmark" : "بازیابی بوکمارک",
    "Delete bookmark permanently" : "حذف دائمی بوکمارک",
    "Content pending" : "محتوای در انتظار",
    "This content is being downloaded for offline use. Please check back later." : "این محتوا برای استفاده آفلاین در حال دانلود است. لطفاً بعداً مراجعه کنید.",
    "Bookmarked {time} ago" : "بوکمارک شده {time} پیش",
    "Bookmarked on {date}" : "بوکمارک شده در {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "این موارد حذف‌شده شما هستند. موارد پس از دو ماه به‌طور دائمی حذف خواهند شد.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "بوکمارک‌های فایل‌های موجود در وب مانند عکس‌ها یا PDFها به‌طور خودکار در فایل‌های نکست‌کلود شما ذخیره می‌شوند، بنابراین حتی زمانی که لینک آفلاین شود، می‌توانید آن‌ها را پیدا کنید.",
    "Searching in the current folder only." : "جستجو فقط در پوشه فعلی",
    "Repeat search in all folders" : "تکرار جستجو در همه پوشه‌ها",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "لینک‌های بوکمارک شده به‌طور منظم بررسی می‌شوند و لینک‌هایی که قابل دسترسی نیستند در اینجا فهرست می‌شوند.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "می‌توانید پوشه‌های بوکمارک را با دیگران به اشتراک بگذارید. همه پوشه‌های به اشتراک گذاشته شده با شما در اینجا فهرست شده‌اند.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "یک بوکمارک می‌تواند هم‌زمان در چندین پوشه باشد. به‌روزرسانی آن، همه نسخه‌ها را به‌روز می‌کند. همه بوکمارک‌های تکراری برای راحتی شما در اینجا فهرست شده‌اند.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} پوشه و {bookmarks} بوکمارک انتخاب شده",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Ø§Ù†ØªØ®Ø§Ø¨ Ø´Ø¯Ù‡ %n Ù†Ø´Ø§Ù†Ú©","Ø§Ù†ØªØ®Ø§Ø¨ Ø´Ø¯Ù‡ %n Ù†Ø´Ø§Ù†Ú© Ù‡Ø§ÛŒ"],
    "_Selected %n folder_::_Selected %n folders_" : ["%n Ù¾ÙˆØ´Ù‡ Ø§Ù†ØªØ®Ø§Ø¨ Ø´Ø¯","%n Ù¾ÙˆØ´Ù‡ Ø§Ù†ØªØ®Ø§Ø¨ Ø´Ø¯"],
    "Do you really want to delete these items?" : "آیا واقعاً می‌خواهید این موارد را حذف کنید؟",
    "Open all selected" : "باز کردن همه موارد انتخاب شده",
    "Move selection" : "انتقال انتخاب",
    "Edit tags of selection" : "ویرایش برچسب‌های انتخاب",
    "Delete selection" : "حذف انتخاب",
    "Select all" : "انتخاب همه",
    "Cancel selection" : "لغو انتخاب",
    "Sort by created date" : "مرتب‌سازی بر اساس تاریخ ایجاد",
    "Sort by last modified" : "مرتب‌سازی بر اساس آخرین تغییر",
    "Sort by title" : "مرتب‌سازی بر اساس عنوان",
    "Sort by click count" : "مرتب‌سازی بر اساس تعداد کلیک",
    "Sort by manual order" : "مرتب‌سازی بر اساس ترتیب دستی",
    "Sort by URL" : "مرتب‌سازی بر اساس URL",
    "RSS feed copied" : "فید RSS کپی شد",
    "Trash Bin" : "سطل زباله",
    "Go back" : "بازگشت",
    "Share folder" : "اشتراک‌گذاری پوشه",
    "Open folder details" : "باز کردن جزئیات پوشه",
    "Select one or more tags" : "یک یا چند برچسب را انتخاب کنید",
    "New" : "جدید",
    "New bookmark" : "بوکمارک جدید",
    "New folder" : "پوشه جدید",
    "Change to grid view" : "تغییر به نمای شبکه‌ای",
    "Change to list view" : "تغییر به نمای لیستی",
    "Copy RSS Feed of current view" : "کپی فید RSS نمای فعلی",
    "The RSS feed requires authentication with your Nextcloud credentials" : "فید RSS نیاز به احراز هویت با اطلاعات کاربری نکست‌کلود شما دارد",
    "Search" : "جستجو",
    "Empty trash bin" : "خالی کردن سطل زباله",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Ø¯Ø± Ø­Ø§Ù„ Ø§Ù�Ø²ÙˆØ¯Ù† %n Ù†Ø´Ø§Ù†Ú© Ø¨Ù‡ Ù¾ÙˆØ´Ù‡Ù” Ø¬Ø¯ÛŒØ¯","Ø¯Ø± Ø­Ø§Ù„ Ø§Ù�Ø²ÙˆØ¯Ù† %n Ù†Ø´Ø§Ù†Ú© Ø¨Ù‡ Ù¾ÙˆØ´Ù‡Ù” Ø¬Ø¯ÛŒØ¯"],
    "Enter a link" : "یک لینک وارد کنید",
    "Enter a title" : "یک عنوان وارد کنید",
    "No bookmarks found" : "هیچ بوکمارکی یافت نشد",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} پوشه و {bookmarks} نشانک",
    "_%n bookmark_::_%n bookmarks_" : ["%n Ù†Ø´Ø§Ù†Ú©","%n Ù†Ø´Ø§Ù†Ú©"],
    "_%n folder_::_%n folders_" : ["%n Ù¾ÙˆØ´Ù‡","%n Ù¾ÙˆØ´Ù‡"],
    "Welcome to Bookmarks" : "به نشانک‌ها خوش آمدید",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "این برنامه به شما امکان مدیریت پیوندهای مکان‌های مورد علاقه در وب را می‌دهد. نشانک‌های خود را در پوشه‌ها مرتب کنید، با برچسب‌ها برچسب‌گذاری کنید و با دیگران به اشتراک بگذارید! برنامه به طور منظم تمام پیوندهای شما را از نظر در دسترس بودن بررسی می‌کند و پیوندهای غیرقابل دسترس را نمایش می‌دهد. اگر پیوندی به یک فایل در وب اضافه کنید، فایل به طور خودکار در نکست‌کلود فایل‌های شما دانلود می‌شود. همچنین می‌توانید نشانک‌های صادر شده از سرویس‌های دیگر را وارد کنید یا مستقیماً نشانک‌ها را از تمام مرورگرهای خود با این برنامه همگام‌سازی کنید.",
    "Add a bookmark" : "افزودن نشانک",
    "Import bookmarks" : "وارد کردن نشانک‌ها",
    "Sync with your browser" : "همگام‌سازی با مرورگر شما",
    "Do you really want to permanently delete this folder?" : "آیا واقعاً می‌خواهید این پوشه را برای همیشه حذف کنید؟",
    "Select folder" : "انتخاب پوشه",
    "Enter folder title" : "عنوان پوشه را وارد کنید",
    "Shared by {user}" : "اشتراک‌گذاری شده توسط {user}",
    "Rename folder" : "تغییر نام پوشه",
    "Move folder" : "انتقال پوشه",
    "Put folder into trashbin" : "انتقال پوشه به سطل زباله",
    "Restore folder" : "بازیابی پوشه",
    "Delete folder permanently" : "حذف دائمی پوشه",
    "Choose folder" : "انتخاب پوشه",
    "Submit" : "ارسال",
    "Cancel" : "لغو",
    "Deleting bookmarks" : "در حال حذف نشانک‌ها",
    "Deleting selection" : "در حال حذف انتخاب",
    "Importing bookmarks" : "در حال وارد کردن نشانک‌ها",
    "Moving selection" : "در حال انتقال انتخاب",
    "Adding selection to folders" : "در حال افزودن انتخاب به پوشه‌ها",
    "Emptying trashbin" : "در حال خالی کردن سطل زباله",
    "Loading trashbin" : "در حال بارگذاری سطل زباله",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %nÙ¾ÙˆØ´Ù‡ Ù‡Ø§ Ùˆ Ø¨Ø±Ø®ÛŒ Ù†Ø´Ø§Ù†Ú© Ù‡Ø§","Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %n Ù¾ÙˆØ´Ù‡ Ù‡Ø§ Ùˆ Ø¨Ø±Ø®ÛŒ Ù†Ø´Ø§Ù†Ú© Ù‡Ø§"],
    "_Moving %n folder_::_Moving %n folders_" : ["Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %n Ù¾ÙˆØ´Ù‡","Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %n Ù¾ÙˆØ´Ù‡ Ù‡Ø§"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %n Ù†Ø´Ø§Ù†Ú©","Ø¯Ø± Ø­Ø§Ù„ Ø§Ù†ØªÙ‚Ø§Ù„ %n Ù†Ø´Ø§Ù†Ú© Ù‡Ø§"],
    "All bookmarks" : "همه نشانک‌ها",
    "Recent" : "اخیراً",
    "Frequently clicked" : "پرکلیک‌ترین",
    "Shared with you" : "اشتراک‌گذاری شده با شما",
    "Files" : "فایل‌ها",
    "Duplicates" : "موارد تکراری",
    "Broken links" : "پیوندهای خراب",
    "New tag" : "برچسب جدید",
    "Search tags" : "جستجوی برچسب‌ها",
    "Delete" : "حذف",
    "Untagged" : "بدون برچسب",
    "{used} bookmarks of {available} available" : "{used} نشانک از {available} نشانک موجود",
    "Bookmarks Settings" : "تنظیمات نشانک‌ها",
    "No bookmarked files" : "هیچ فایل نشانک‌گذاری شده‌ای وجود ندارد",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "نشانک‌های فایل‌هایی مانند عکس‌ها یا PDFها به طور خودکار در فایل‌های نکست‌کلود شما ذخیره می‌شوند، بنابراین حتی زمانی که پیوند آفلاین می‌شود، همچنان می‌توانید آن‌ها را پیدا کنید.",
    "Nothing found" : "چیزی یافت نشد",
    "Your search yielded no results in the current folder." : "جستجوی شما در پوشه فعلی نتیجه‌ای نداشت.",
    "No broken links" : "هیچ پیوند خرابی وجود ندارد",
    "No shared folders" : "هیچ پوشه اشتراک‌گذاری شده‌ای وجود ندارد",
    "No duplicated bookmarks" : "هیچ نشانک تکراری وجود ندارد",
    "No deleted bookmarks" : "هیچ نشانک حذف شده‌ای وجود ندارد",
    "You haven't deleted anything yet." : "هنوز چیزی حذف نکرده‌اید.",
    "No bookmarks here" : "اینجا هیچ نشانکی وجود ندارد",
    "Add bookmarks manually or import bookmarks from a HTML file." : "نشانک‌ها را به صورت دستی اضافه کنید یا از یک فایل HTML وارد کنید.",
    "Archive path" : "مسیر بایگانی",
    "Backup path" : "مسیر پشتیبان‌گیری",
    "Please select \"Add to home screen\" in your browser menu" : "لطفاً در منوی مرورگر خود گزینه «افزودن به صفحه اصلی» را انتخاب کنید",
    "Bookmarks settings" : "تنظیمات نشانک‌ها",
    "Import/Export" : "ورود/خروج",
    "Export bookmarks" : "خروجی گرفتن از نشانک‌ها",
    "Auto-archiving" : "بایگانی خودکار",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "برنامه نشانک‌ها می‌تواند به طور خودکار محتوای وب لینک‌هایی که نشانک کرده‌اید را بایگانی کند",
    "Enable archiving" : "فعال‌سازی بایگانی",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "مسیر پوشه‌ای در فایل‌های خود را وارد کنید که فایل‌های نشانک‌گذاری شده در آن ذخیره شوند.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "در حال حاضر مدیر شما دسترسی شبکه را برای این برنامه غیرفعال کرده است، به همین دلیل بایگانی خودکار در حال حاضر غیرفعال است.",
    "Auto-Backup" : "پشتیبان‌گیری خودکار",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "برنامه نشانک‌ها می‌تواند به طور خودکار روزانه از نشانک‌های شما پشتیبان‌گیری کند تا از از دست رفتن داده‌ها هنگام همگام‌سازی نشانک‌ها در دستگاه‌های مختلف جلوگیری کند.",
    "Enable backups" : "فعال‌سازی پشتیبان‌گیری",
    "Enter the path of a folder in your Files where backups will be stored." : "مسیر پوشه‌ای در فایل‌های خود را وارد کنید که پشتیبان‌ها در آن ذخیره شوند.",
    "Context Chat integration" : "یکپارچه‌سازی چت متنی",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "برنامه نشانک‌ها می‌تواند به طور خودکار محتوای متنی وب‌سایت‌هایی که نشانک می‌کنید را در اختیار چت متنی قرار دهد، که امکان پرسیدن سوال و دریافت پاسخ بر اساس آن محتوا را فراهم می‌کند. این ویژگی فقط در صورت فعال بودن بایگانی خودکار در دسترس است.",
    "Context chat is currently not installed, but is required for this feature." : "چت متنی در حال حاضر نصب نشده است، اما برای این ویژگی ضروری است.",
    "Enable Context Chat integration" : "فعال‌سازی یکپارچه‌سازی چت متنی",
    "Client apps" : "برنامه‌های کلاینت",
    "Also check out the collection of client apps that integrate with this app: " : "همچنین مجموعه برنامه‌های کلاینتی که با این برنامه یکپارچه می‌شوند را بررسی کنید:",
    "Install web app" : "نصب برنامه وب",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "می‌توانید این برنامه را روی صفحه اصلی دستگاه خود نصب کنید تا در تلفن خود به سرعت به نشانک‌های خود دسترسی داشته باشید. اگر دوست نداشتید، می‌توانید به راحتی برنامه را دوباره از صفحه اصلی حذف کنید.",
    "Install on home screen" : "نصب روی صفحه اصلی",
    "Bookmarklet" : "بوکمارکلت",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "این را به نشانک‌های مرورگر خود بکشید و روی آن کلیک کنید تا به سرعت یک صفحه وب را نشانک کنید.",
    "Add to {instanceName}" : "افزودن به {instanceName}",
    "Need help?" : "نیاز به کمک دارید؟",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "اگر با این برنامه نشانک‌ها مشکلی دارید یا ایده‌ای برای بهبود آن دارید، با کلیک کردن در اینجا با ما تماس بگیرید.",
    "Support this project" : "از این پروژه حمایت کنید",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "کار من روی این برنامه نشانک‌ها با یک مدل اشتراک داوطلبانه پیش می‌رود. اگر فکر می‌کنید کاری که انجام می‌دهم ارزشمند است، خوشحال می‌شوم که از کار من پشتیبانی کنید. همچنین لطفاً نوشتن یک نقد برای این برنامه در فروشگاه برنامه‌های Nextcloud را در نظر بگیرید. سپاسگزارم 💙 ",
    "Created {time} ago" : "ایجاد شده {time} پیش",
    "Created on {date}" : "ایجاد شده در {date}",
    "(Empty title)" : "(عنوان خالی)",
    "Title" : "عنوان",
    "Link" : "لینک",
    "Untitled folder" : "پوشه بدون نام",
    "Root folder" : "پوشه ریشه",
    "Tags" : "برچسب‌ها",
    "Select tags and create new ones" : "برچسب‌ها را انتخاب کنید و برچسب‌های جدید ایجاد کنید",
    "Notes" : "یادداشت‌ها",
    "Notes for this bookmark …" : "یادداشت‌هایی برای این نشانک …",
    "Archived file" : "فایل بایگانی شده",
    "Open file" : "باز کردن فایل",
    "Download file" : "دانلود فایل",
    "Open file location" : "باز کردن محل فایل",
    "Link copied" : "لینک کپی شد",
    "Owner" : "مالک",
    "Sharing" : "اشتراک‌گذاری",
    "Select a user or group" : "یک کاربر یا گروه را انتخاب کنید",
    "Share link" : "اشتراک پیوند",
    "Reading allowed" : "اجازه خواندن",
    "Copy RSS feed" : "کپی خوراک RSS",
    "Delete link" : "حذف پیوند",
    "Create public link" : "ایجاد پیوند عمومی",
    "Resharing allowed" : "اجازه اشتراک‌گذاری مجدد",
    "Editing allowed" : "اجازه ویرایش",
    "Allow editing" : "اجازه ویرایش",
    "Allow resharing" : "اجازه اشتراک‌گذاری مجدد",
    "Remove share" : "حذف اشتراک",
    "Would you like to support this project?" : "آیا مایل به حمایت از این پروژه هستید؟",
    "Leave a rating on the Nextcloud App Store" : "در فروشگاه نکست‌کلود امتیاز دهید",
    "Failed to save settings" : "ذخیره تنظیمات انجام نشد",
    "Failed to load settings" : "بارگیری تنظیمات انجام نشد",
    "Privacy" : "حریم خصوصی",
    "The app will try to access web pages that you add to automatically add information about them." : "برنامه سعی می‌کند به صفحات وبی که اضافه می‌کنید دسترسی پیدا کند تا به‌طور خودکار اطلاعاتی درباره آن‌ها اضافه کند.",
    "Enable accessing and collecting information from the web pages you add" : "فعال‌سازی دسترسی و جمع‌آوری اطلاعات از صفحات وب اضافه‌شده",
    "Performance" : "عملکرد",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "در نصب‌هایی با کاربران زیاد، محدود کردن تعداد نشانک‌ها در هر حساب ممکن است مفید باشد.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "حداکثر تعداد مجاز نشانک در هر حساب (0 به معنی بدون محدودیت؛ پیش‌فرض بدون محدودیت است)",
    "Previews" : "پیش‌نمایش‌ها",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "برای نمایش تصاویر واقعی از وب‌سایت‌های نشانک‌شده، برنامه می‌تواند از سرویس‌های شخص ثالث برای تولید پیش‌نمایش استفاده کند.",
    "Screeenly" : "اسکرین‌لی",
    "You can either sign up for free at screeenly.com or setup your own server." : "می‌توانید به‌صورت رایگان در screeenly.com ثبت‌نام کنید یا سرور خود را راه‌اندازی کنید.",
    "Screeenly API URL" : "آدرس API اسکرین‌لی",
    "Screeenly API key" : "کلید API اسکرین‌لی",
    "ScreenshotMachine" : "اسکرین‌شات‌ماشین",
    "ScreenshotMachine API key" : "کلید API اسکرین‌شات‌ماشین",
    "Webshot" : "وب‌شات",
    "Webshot API URL" : "آدرس API وب‌شات",
    "Generic screenshot API" : "API پیش‌نمایش عمومی",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "با هر یک از ارائه‌دهندگان API پیش‌نمایش ثبت‌نام کنید و آدرس API را در زیر قرار دهید. از متغیر {url} به‌عنوان جایگزین برای آدرس اینترنتی پیش‌نمایش استفاده کنید. API باید فقط تصویر را مستقیماً برگرداند.",
    "Generic API URL" : "آدرس API عمومی",
    "Pageres CLI" : "رابط خط فرمان Pageres",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "کافی است رابط خط فرمان Pageres را توسط Sindre Sorhus روی سرور خود نصب کنید و نشانک‌ها آن را پیدا خواهند کرد. همچنان می‌توانید متغیرهای محیطی اضافی برای تغذیه به Pageres اضافه کنید، مثلاً همان‌طور که در جایگزین نشان داده شده است:",
    "Pageres ENV variables" : "متغیرهای محیطی Pageres",
    "This URL is already bookmarked! Overwrite?" : "این آدرس قبلاً نشانک شده است! بازنویسی شود؟",
    "Enter bookmark title" : "عنوان نشانک را وارد کنید",
    "Enter bookmark URL" : "آدرس نشانک را وارد کنید",
    "Folder" : "پوشه",
    "Root Folder" : "پوشه ریشه",
    "Save" : "ذخیره",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "دسترسی به شبکه به‌طور پیش‌فرض غیرفعال است. برای اجازه دریافت پیش‌نمایش‌ها و نمادها به تنظیمات مدیر برای برنامه نشانک‌ها بروید.",
    "What's new?" : "چه خبر؟",
    "What" : "چه",
    "Failed to count unavailable bookmarks" : "شمارش نشانک‌های در دسترس انجام نشد",
    "Failed to count archived bookmarks" : "شمارش نشانک‌های بایگانی‌شده انجام نشد",
    "Failed to count deleted bookmarks" : "شمارش نشانک‌های حذف‌شده انجام نشد",
    "Failed to count duplicated bookmarks" : "شمارش نشانک‌های تکراری انجام نشد",
    "Failed to count bookmarks" : "شمارش نشانک‌ها انجام نشد",
    "Failed to load bookmark" : "بارگذاری نشانک انجام نشد",
    "Failed to find existing bookmark" : "نشانک موجود پیدا نشد",
    "Failed to create bookmark" : "ایجاد نشانک انجام نشد",
    "Failed to save bookmark" : "ذخیره‌سازی نشانک انجام نشد",
    "Failed to move bookmark" : "جابجایی نشانک انجام نشد",
    "Failed to copy bookmark" : "کپی کردن نشانک انجام نشد",
    "Failed to delete bookmark" : "حذف نشانک انجام نشد",
    "Failed to restore bookmark" : "بازیابی نشانک انجام نشد",
    "Import successful" : "واردات با موفقیت انجام شد",
    "Failed to rename tag" : "تغییر نام برچسب انجام نشد",
    "Failed to load tags" : "بارگذاری برچسب‌ها انجام نشد",
    "Failed to load folders" : "بارگذاری پوشه‌ها انجام نشد",
    "Failed to load deleted folders" : "بارگذاری پوشه‌های حذف‌شده انجام نشد",
    "Failed to load deleted bookmarks" : "بارگذاری نشانک‌های حذف‌شده انجام نشد",
    "Failed to delete folder" : "حذف پوشه انجام نشد",
    "Failed to move folder" : "جابجایی پوشه انجام نشد",
    "Failed to restore folder" : "بازیابی پوشه انجام نشد",
    "Failed to create folder" : "ایجاد پوشه انجام نشد",
    "Failed to load children order" : "بارگذاری ترتیب فرزندان انجام نشد",
    "Failed to move parts of selection" : "جابجایی بخش‌هایی از انتخاب انجام نشد",
    "Failed to copy parts of selection" : "کپی بخش‌هایی از انتخاب انجام نشد",
    "Failed to delete parts of selection" : "حذف بخش‌هایی از انتخاب انجام نشد",
    "Failed to tag parts of selection" : "برچسب‌گذاری بخش‌هایی از انتخاب انجام نشد",
    "Failed to fetch bookmarks." : "دریافت نشانک‌ها انجام نشد",
    "Failed to store setting" : "ذخیره‌سازی تنظیمات انجام نشد",
    "Failed to load setting {key}" : "بارگذاری تنظیمات {key} انجام نشد",
    "Failed to create share for folder {folderId}" : "ایجاد اشتراک برای پوشه {folderId} انجام نشد",
    "Failed to update share {shareId}" : "به‌روزرسانی اشتراک {shareId} انجام نشد",
    "Failed to delete share {shareId}" : "حذف اشتراک {shareId} انجام نشد",
    "Failed to create public link for folder {folderId}" : "ایجاد لینک عمومی برای پوشه {folderId} انجام نشد",
    "Failed to delete public link for folder {folderId}" : "حذف لینک عمومی برای پوشه {folderId} انجام نشد",
    "Failed to permanently delete parts of trash bin" : "حذف دائمی بخش‌هایی از سطل زباله انجام نشد",
    "Create bookmarks for mentioned links" : "ایجاد نشانک برای لینک‌های ذکر شده",
    "No links found in this message" : "هیچ لینکی در این پیام یافت نشد",
    "Bookmarks feed" : "فید نشانک‌ها"
},
"nplurals=2; plural=(n > 1);");
