OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bookmarks",
    "You bookmarked \"%s\"" : "Je bookmarkte \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s bookmarkte \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Iemand bookmarkte \"%s\"",
    "You deleted \"%s\"" : "Je verwijderde \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s verwijderde \"%2$s\"",
    "Someone deleted \"%s\"" : "Iemand verwijderde \"%s\"",
    "You created folder \"%s\"" : "Je maakte de map \"%s\" aan",
    "%1$s created folder \"%2$s\"" : "%1$smaakte map \"%2$s\" aan",
    "Someone created folder \"%s\"" : "Iemand maakte de map \"%s\" aan",
    "You moved folder \"%s\"" : "Je verplaatste de map \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s verplaatste map \"%2$s\"",
    "Someone moved folder \"%s\"" : "Iemand verplaatste de map \"%s\"",
    "You deleted folder \"%s\"" : "Je verwijderde de map \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s verwijderde de map \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Iemand verwijderde de map \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Je deelde de map \"%1$s\" met %2$s",
    "You shared folder \"%s\" with someone" : "Je deelde de map \"%s\" met iemand",
    "%1$s shared folder \"%2$s\" with you" : "%1$s deelde de map \"%2$s\" met je",
    "Someone shared folder \"%s\" with you" : "Iemand deelde de map \"%s\" met je",
    "You unshared folder \"%1$s\" with %2$s" : "Jouw map \"%1$s\" is niet meer gedeeld met %2$s",
    "You unshared folder \"%s\" with someone" : "Jouw map \"%s\" is niet meer gedeeld met iemand",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s heeft zijn map \"%2$s\" niet meer met jou gedeeld",
    "Someone unshared folder \"%s\" with you" : "Iemand heeft zijn map \"%s\" niet meer met jou gedeeld",
    "No file provided for import" : "Geen bestand aangeboden om te importeren",
    "Failed to upload file" : "Kon bestand niet uploaden",
    "Unsupported file type for import: " : "Bestandstype wordt niet ondersteund voor import:",
    "Bookmarks shared by %s" : "Bookmarks gedeeld door %s",
    "Frequent bookmarks" : "frequente bookmarks",
    "Recent bookmarks" : "Recente bookmarks",
    "Bookmark" : "Bookmark",
    "Bookmark deleted" : "Bookmark verwijderd",
    "Bookmark created" : "Bookmark aangemaakt",
    "Bookmark moved" : "Bookmark verplaatst",
    "Bookmark updated" : "Bookmark bijgewerkt",
    "Create bookmark" : "Maak bookmark aan",
    "Takes a link and adds it to your collection of bookmarks." : "Neemt een link en voegt deze toe aan je verzameling van bookmarks.",
    "Bookmarks Backups" : "Bookmarks back-ups",
    "Collect and manage bookmarks, synced with all your devices" : "Bookmarks verzamelen en beheren, gesynchroniseerd met al je apparaten",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Sorteer bookmarks in mappen\n- 🏷 Voeg tags en persoonlijke notities toe\n- ☠ Vind kapotte links en duplicaten\n- 📲 Synchroniseer met al je browsers en apparaten\n- 📔 Bewaar gearchiveerde versies van je links voor het geval ze offline worden gehaald\n- 🔍 Doorzoek de volledige tekst van website-inhoud\n- 👪 Deel bladwijzers met andere gebruikers, groepen en teams of via openbare links\n- ⚛ Genereer RSS-feeds van je collecties\n- 📈 Statistieken over hoe vaak je welke links opent\n- 🔒 Automatische back-ups van je bookmarkcollectie\n- 💼 Ingebouwde dashboardwidgets voor vaak gebruikte en recente links\n\nVereisten:\n - PHP-extensies:\n   - intl: *\n   - mbstring: *\n - Gebruik bij MySQL minimaal versie 8.0",
    "Do you really want to delete this bookmark?" : "Wil je deze bladwijzer echt verwijderen?",
    "Link copied to clipboard" : "Link gekopieerd naar het klembord",
    "Enter new title" : "Voer nieuwe titel in",
    "Select bookmark" : "Selecteer bookmark",
    "You have never clicked this link" : "Je hebt nog nooit op deze link geklikt",
    "You have clicked this link {count} times" : "Je hebt deze link {count} keer aangeklikt",
    "Details" : "Details",
    "Rename" : "Hernoemen",
    "Copy link" : "Link kopiëren",
    "Move" : "Verplaatsen",
    "Add to folders" : "Voeg toe aan mappen",
    "Put bookmark into trash bin" : "Verplaats bookmark naar prullenbak",
    "Restore bookmark" : "Bookmark herstellen",
    "Delete bookmark permanently" : "Bookmark permanent verwijderen",
    "Content pending" : "Content in behandeling",
    "This content is being downloaded for offline use. Please check back later." : "Deze inhoud wordt gedownload voor offline gebruik. Kom later nog eens terug.",
    "Bookmarked {time} ago" : "{time}geleden gebookmarked",
    "Bookmarked on {date}" : "Gebookmarked op {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Dit zijn je verwijderde items. De items worden na twee maanden definitief verwijderd.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bladwijzers naar bestanden op het web zoals foto's of PDFs zullen automatisch opgeslagen worden in je Nextcloud bestanden zodat je ze nog kunt vinden, zelfs als de link offline gaat.",
    "Searching in the current folder only." : "Alleen zoeken in de huidige map.",
    "Repeat search in all folders" : "Zoek opnieuw in alle mappen",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Geselecteerde {folders} mappen en {bookmarks} bookmarks",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Geselecteerde %n bladwijzer","Geselecteerde %n bookmarks"],
    "_Selected %n folder_::_Selected %n folders_" : ["Selecteerde %n map","Selecteerde %n mappen"],
    "Do you really want to delete these items?" : "Wil je deze objecten echt verwijderen?",
    "Open all selected" : "Open alle geselecteerde",
    "Move selection" : "Verplaats selectie",
    "Edit tags of selection" : "Bewerk de labels van de selectie",
    "Delete selection" : "Verwijder selectie",
    "Select all" : "Alles selecteren",
    "Cancel selection" : "Annuleren selectie",
    "Sort by created date" : "Sorteer op aanmaakdatum",
    "Sort by last modified" : "Op wijzigingsdatum sorteren",
    "Sort by title" : "Sorteer op titel",
    "Sort by click count" : "Sorteren op aantal doorkliks",
    "Sort by manual order" : "Sorteer op handmatige volgorde.",
    "Sort by URL" : "Sorteer op URL",
    "RSS feed copied" : "RSS Feed gekopieerd",
    "Trash Bin" : "Prullenbak",
    "Go back" : "Ga terug",
    "Share folder" : "Delen map",
    "Select one or more tags" : "Kies één of meer tags",
    "New" : "Nieuw",
    "New bookmark" : "Nieuwe bookmark",
    "New folder" : "Nieuwe map",
    "Change to grid view" : "Omschakelen roosterweergave",
    "Change to list view" : "Omschakelen naar lijstweergave",
    "Copy RSS Feed of current view" : "Kopieer RSS feed van huidige weergave",
    "The RSS feed requires authentication with your Nextcloud credentials" : "De RSS-feed vereist authenticatie met je Nextcloud-inloggegevens",
    "Search" : "Zoeken",
    "Empty trash bin" : "Prullenbak legen",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Voeg %n bladwijzers toe aan nieuwe map","Voeg %n bladwijzers toe aan nieuwe map"],
    "Enter a link" : "Voer een link in",
    "Enter a title" : "Voer een titel in",
    "No bookmarks found" : "Geen bladwijzers gevonden",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mappen en {bookmarks} bladwijzers",
    "_%n bookmark_::_%n bookmarks_" : ["%n bladwijzer","%n bladwijzers"],
    "_%n folder_::_%n folders_" : ["%n map","%n mappen"],
    "Welcome to Bookmarks" : "Welkom bij bookmarks",
    "Add a bookmark" : "Voeg een bladwijzer toe",
    "Import bookmarks" : "Importeer bladwijzers",
    "Sync with your browser" : "Sync met je browser",
    "Do you really want to permanently delete this folder?" : "Wil je deze map echt definitief verwijderen?",
    "Select folder" : "Selecteer map",
    "Enter folder title" : "Geef maptitel op",
    "Shared by {user}" : "Gedeeld door {user}",
    "Rename folder" : "Hernoem map",
    "Move folder" : "Verplaatsen map",
    "Put folder into trashbin" : "Verplaats map naar prullenbak",
    "Restore folder" : "Map herstellen",
    "Delete folder permanently" : "Map permanent verwijderen",
    "Choose folder" : "Kies map",
    "Submit" : "Verwerken",
    "Cancel" : "Annuleren",
    "Deleting bookmarks" : "Bladwijzers verwijderen",
    "Deleting selection" : "Selectie verwijderen",
    "Importing bookmarks" : "Bladwijzers importeren",
    "Moving selection" : "Selectie verplaatsen",
    "Adding selection to folders" : "Selectie aan mappen toevoegen",
    "Emptying trashbin" : "Prullenbak aan het leegmaken",
    "Loading trashbin" : "Prullenbak inladen",
    "Restoring folder" : "Map aan het herstellen",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["%n folder en bladwijzers verplaatsen","%n mappen en bookmarks verplaatsen"],
    "_Moving %n folder_::_Moving %n folders_" : ["%n folder verplaatsen","%n mappen verplaatsen"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["%n bladwijzer verplaatsen","%n bladwijzers verplaatsen"],
    "All bookmarks" : "Alle bladwijzers",
    "Recent" : "Recent",
    "Frequently clicked" : "Meest aangeklikt",
    "Shared with you" : "Gedeeld met jou",
    "Files" : "Bestanden",
    "Duplicates" : "Duplicaten",
    "Broken links" : "Niet-werkende links",
    "New tag" : "Nieuwe tag",
    "Search tags" : "Zoek in tags",
    "Delete" : "Verwijderen",
    "Untagged" : "Niet getagd",
    "{used} bookmarks of {available} available" : "{used} bladwijzers van {available} beschikbare",
    "Bookmarks Settings" : "Bookmark instellingen",
    "No bookmarked files" : "Geen bladwijzers voor bestanden",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bladwijzers naar bestanden zoals foto's of PDF's worden automatisch opgeslagen in je Nextcloud bestanden, zodat je ze nog steeds kunt vinden, zelfs als de link offline gaat.",
    "Nothing found" : "Niets gevonden",
    "No broken links" : "Geen gebroken links",
    "No shared folders" : "Geen gedeelde mappen",
    "No duplicated bookmarks" : "Geen duplicaat bladwijzers",
    "No deleted bookmarks" : "Geen verwijderde bookmarks",
    "You haven't deleted anything yet." : "Je hebt nog niets verwijderd.",
    "No bookmarks here" : "Geen bookmarks hier",
    "Archive path" : "Archief pad",
    "Backup path" : "Back-up pad",
    "Please select \"Add to home screen\" in your browser menu" : "Selecteer 'Voeg toe aan thuisscherm' in je browser menu",
    "Bookmarks settings" : "Bookmark instellingen",
    "Import/Export" : "Importeer/Exporteer",
    "Export bookmarks" : "Exporteer bookmarks",
    "Auto-archiving" : "Automatisch archiveren",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "De bookmarks-app kan de webinhoud van links die je als bladwijzer hebt opgeslagen automatisch archiveren",
    "Enable archiving" : "Archivering inschakelen",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Voer het pad van een map in je Bestanden in waar bladwijzers opgeslagen moeten worden.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Op dit moment heeft je beheerder de netwerktoegang voor deze app uitgeschakeld, waardoor automatische archivering momenteel niet beschikbaar is.",
    "Enable backups" : "Back-ups inschakelen",
    "Context Chat integration" : "Context Chat-integratie",
    "Client apps" : "Client apps",
    "Also check out the collection of client apps that integrate with this app: " : "Bekijk ook de verzameling client-apps die met deze app kunnen worden geïntegreerd:",
    "Install web app" : "Installeer web-app",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Je kunt deze app op het startscherm van je toestel installeren om daarmee snel toegang te krijgen tot de bladwijzers op je telefoon. Je kunt de app eenvoudig weer van je startscherm verwijderen, als je die niet leuk vindt.",
    "Install on home screen" : "Installeren op thuisscherm",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Sleep dit naar je browser bladwijzers en open het om snel een bladwijzer van een website te maken.",
    "Add to {instanceName}" : "Toevoegen aan {instanceName}",
    "Need help?" : "Hulp nodig?",
    "Support this project" : "Steun dit project",
    "Created {time} ago" : "{time} geleden gecreëerd",
    "Created on {date}" : "Aangemaakt op {date}",
    "Title" : "Titel",
    "Link" : "Link",
    "Untitled folder" : "Naamloze map",
    "Root folder" : "Hoofdmap",
    "Tags" : "Tags",
    "Select tags and create new ones" : "Selecteer tags en maak nieuwe aan",
    "Notes" : "Notities",
    "Notes for this bookmark …" : "Notities voor deze bladwijzer...",
    "Archived file" : "Gearchiveerd bestand",
    "Open file" : "Openen bestand",
    "Download file" : "Downloaden bestand",
    "Open file location" : "Open bestandslocatie",
    "Link copied" : "Link gekopieerd",
    "Owner" : "Eigenaar",
    "Sharing" : "Delen",
    "Select a user or group" : "Kies een gebruiker of groep",
    "Share link" : "Link delen",
    "Reading allowed" : "Lezen toegestaan",
    "Copy RSS feed" : "Kopieer RSS Feed",
    "Delete link" : "Verwijder link",
    "Create public link" : "Creëer openbare link",
    "Resharing allowed" : "Opnieuw delen toegestaan",
    "Editing allowed" : "Bewerken toegestaan",
    "Allow editing" : "Bewerken toestaan",
    "Allow resharing" : "Opnieuw delen toestaan",
    "Remove share" : "Verwijder share",
    "Would you like to support this project?" : "Zou je dit project willen steunen?",
    "Leave a rating on the Nextcloud App Store" : "Laat een beoordeling achter in de NextCloud App Store",
    "Failed to save settings" : "Kon instellingen niet opslaan",
    "Failed to load settings" : "Kon instellingen niet laden",
    "Privacy" : "Privacy",
    "Enable accessing and collecting information from the web pages you add" : "Schakel toegang tot en het verzamelen van informatie in van de webpagina's die je toevoegt",
    "Performance" : "Prestaties",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Bij een installatie met veel gebruikers kan het handig zijn om het aantal bladwijzers per account te beperken.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximaal toegestaan aantal bladwijzers per account. (0 voor geen limiet; standaard is geen limiet)",
    "Previews" : "Voorbeeldweergaven",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Je kunt je gratis aanmelden op screeenly.com of je eigen server instellen.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API-sleutel",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API-sleutel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Pageres CLI" : "Pageres CLI",
    "This URL is already bookmarked! Overwrite?" : "Deze URL is al als bladwijzer aangemerkt! Overschrijven?",
    "Enter bookmark title" : "Voer bladwijzertitel in",
    "Enter bookmark URL" : "Geef bladwijzer-URL op",
    "Folder" : "Map",
    "Root Folder" : "Hoofdmap",
    "Save" : "Opslaan",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Netwerktoegang is standaard uitgeschakeld. Ga naar de beheerdersinstellingen voor de bladwijzer-app om het ophalen van voorbeelden en favicons toe te staan.",
    "What's new?" : "Wat is nieuw?",
    "What" : "Wat",
    "Failed to count unavailable bookmarks" : "Het tellen van niet-beschikbare bladwijzers is mislukt",
    "Failed to count archived bookmarks" : "Het tellen van gearchiveerde bladwijzers is mislukt",
    "Failed to load bookmark" : "Kan bladwijzer niet laden",
    "Failed to find existing bookmark" : "Kon bestaande bladwijzer niet vinden",
    "Failed to create bookmark" : "Kon bladwijzer niet aanmaken",
    "Failed to save bookmark" : "Kon bladwijzer niet bewaren",
    "Failed to move bookmark" : "Kon bladwijzer niet verplaatsen",
    "Failed to copy bookmark" : "Kan bladwijzer niet kopiëren",
    "Failed to delete bookmark" : "Kon bladwijzer niet verwijderen",
    "Import successful" : "Import geslaagd",
    "Failed to rename tag" : "Wijzigen naam van label mislukt",
    "Failed to load tags" : "Kon tags niet laden",
    "Failed to load folders" : "Kon mappen niet laden",
    "Failed to delete folder" : "Kon map niet verwijderen",
    "Failed to create folder" : "Kon map niet aanmaken",
    "Failed to move parts of selection" : "Kon delen van de delen van de selectie niet verplaatsen",
    "Failed to delete parts of selection" : "Kan delen van selectie niet verwijderen",
    "Failed to fetch bookmarks." : "Kon bladwijzer niet ophalen",
    "Failed to load setting {key}" : "Kon instelling niet laden {key}",
    "Failed to update share {shareId}" : "Share uploaden mislukt {shareId}",
    "Failed to delete share {shareId}" : "Kan de share niet verwijderen {shareId}",
    "No links found in this message" : "Geen links in dit bericht gevonden",
    "Bookmarks feed" : "Bladwijzerfeed"
},
"nplurals=2; plural=(n != 1);");
