OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "ບຸກມາກ",
    "You bookmarked \"%s\"" : "ທ່ານໄດ້ບຸກມາກ \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s ໄດ້ບຸກມາກ \"%2$s\"",
    "Someone bookmarked \"%s\"" : "ມີບາງຄົນບຸກມາກ \"%s\"",
    "You deleted \"%s\"" : "ທ່ານໄດ້ລຶບ \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s ໄດ້ລຶບ \"%2$s\"",
    "Someone deleted \"%s\"" : "ມີບາງຄົນລຶບ \"%s\"",
    "You created folder \"%s\"" : "ທ່ານໄດ້ສ້າງໂຟນເດີ \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s ໄດ້ສ້າງໂຟນເດີ \"%2$s\"",
    "Someone created folder \"%s\"" : "ມີບາງຄົນສ້າງໂຟນເດີ \"%s\"",
    "You moved folder \"%s\"" : "ທ່ານໄດ້ຍ້າຍໂຟນເດີ \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s ໄດ້ຍ້າຍໂຟນເດີ \"%2$s\"",
    "Someone moved folder \"%s\"" : "ມີບາງຄົນຍ້າຍໂຟນເດີ \"%s\"",
    "You deleted folder \"%s\"" : "ທ່ານໄດ້ລຶບໂຟນເດີ \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s ໄດ້ລຶບໂຟນເດີ \"%2$s\"",
    "Someone deleted folder \"%s\"" : "ມີບາງຄົນລຶບໂຟນເດີ \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "ທ່ານໄດ້ແບ່ງປັນໂຟນເດີ \"%1$s\" ໃຫ້ກັບ %2$s",
    "You shared folder \"%s\" with someone" : "ທ່ານໄດ້ແບ່ງປັນໂຟນເດີ \"%s\" ໃຫ້ກັບບາງຄົນ",
    "%1$s shared folder \"%2$s\" with you" : "%1$s ໄດ້ແບ່ງປັນໂຟນເດີ \"%2$s\" ໃຫ້ກັບທ່ານ",
    "Someone shared folder \"%s\" with you" : "ມີບາງຄົນແບ່ງປັນໂຟນເດີ \"%s\" ໃຫ້ກັບທ່ານ",
    "You unshared folder \"%1$s\" with %2$s" : "ທ່ານໄດ້ຍົກເລີກການແບ່ງປັນໂຟນເດີ \"%1$s\" ໃຫ້ກັບ %2$s",
    "You unshared folder \"%s\" with someone" : "ທ່ານໄດ້ຍົກເລີກການແບ່ງປັນໂຟນເດີ \"%s\" ໃຫ້ກັບບາງຄົນ",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s ໄດ້ຍົກເລີກການແບ່ງປັນໂຟນເດີ \"%2$s\" ກັບທ່ານ",
    "Someone unshared folder \"%s\" with you" : "ມີບາງຄົນຍົກເລີກການແບ່ງປັນໂຟນເດີ \"%s\" ກັບທ່ານ",
    "No file provided for import" : "ບໍ່ມີໄຟລ໌ສຳລັບການນຳເຂົ້າ",
    "Failed to upload file" : "ອັບໂຫຼດໄຟລ໌ບໍ່ສຳເລັດ",
    "Unsupported file type for import: " : "ປະເພດໄຟລ໌ທີ່ບໍ່ຮອງຮັບສຳລັບການນຳເຂົ້າ: ",
    "Bookmarks shared by %s" : "ບຸກມາກທີ່ແບ່ງປັນໂດຍ %s",
    "Frequent bookmarks" : "ບຸກມາກທີ່ໃຊ້ເລື້ອຍໆ",
    "Recent bookmarks" : "ບຸກມາກຫວ່າງບໍ່ດົນມານີ້",
    "Bookmark" : "ບຸກມາກ",
    "Bookmark deleted" : "ລຶບບຸກມາກແລ້ວ",
    "Bookmark created" : "ສ້າງບຸກມາກແລ້ວ",
    "Bookmark moved" : "ຍ້າຍບຸກມາກແລ້ວ",
    "Bookmark updated" : "ອັບເດດບຸກມາກແລ້ວ",
    "Create bookmark" : "ສ້າງບຸກມາກ",
    "Takes a link and adds it to your collection of bookmarks." : "ຮັບລິ້ງ ແລະ ເພີ່ມໃສ່ໃນບ່ອນເກັບບຸກມາກຂອງທ່ານ.",
    "Bookmarks Backups" : "ສຳຮອງຂໍ້ມູນບຸກມາກ",
    "Collect and manage bookmarks, synced with all your devices" : "ຮວບຮວມ ແລະ ຈັດການບຸກມາກ, ຊິ້ງຄ໌ກັບທຸກອຸປະກອນຂອງທ່ານ",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 ຈັດຮຽງບຸກມາກໃສ່ໃນໂຟນເດີ\n- 🏷 ເພີ່ມແທັກ ແລະ ບັນທຶກສ່ວນຕົວ\n- ☠ ຄົ້ນຫາລິ້ງທີ່ໃຊ້ການບໍ່ໄດ້ ແລະ ລິ້ງທີ່ຊ້ຳກັນ\n- 📲 ຊິ້ງຄ໌ກັບທຸກບຣາວເຊີ ແລະ ອຸປະກອນຂອງທ່ານ\n- 📔 ເກັບເວີຊັນເກົ່າຂອງລິ້ງໄວ້ ໃນກໍລະນີທີ່ລິ້ງນັ້ນຖືກລຶບອອກຈາກເວັບໄຊ\n- 🔍 ຄົ້ນຫາຂໍ້ຄວາມທັງໝົດໃນເນື້ອຫາເວັບໄຊ\n- 👪 ແບ່ງປັນບຸກມາກກັບຜູ້ໃຊ້ອື່ນ, ກຸ່ມ ແລະ ທີມ ຫຼື ຜ່ານລິ້ງສາທາລະນະ\n- ⚛ ສ້າງ RSS feeds ຈາກບຸກມາກຂອງທ່ານ\n- 📈 ສະຖິຕິການເຂົ້າເຖິງແຕ່ລະລິ້ງ\n- 🔒 ສຳຮອງຂໍ້ມູນບຸກມາກຂອງທ່ານແບບອັດຕະໂນມັດ\n- 💼 ວິດເຈັດ Dashboard ໃນຕົວ ສຳລັບລິ້ງທີ່ໃຊ້ເລື້ອຍໆ ແລະ ຫວ່າງບໍ່ດົນມານີ້\n\nຄວາມຕ້ອງການ:\n - ສ່ວນເສີມ PHP:\n   - intl: *\n   - mbstring: *\n - ຖ້າໃຊ້ MySQL, ຕ້ອງເປັນເວີຊັນ v8.0 ຂຶ້ນໄປ",
    "Do you really want to delete this bookmark?" : "ທ່ານຕ້ອງການລຶບບຸກມາກນີ້ແທ້ຫຼືບໍ່?",
    "Link copied to clipboard" : "ສຳເນົາລິ້ງໃສ່ຄລິບບອດແລ້ວ",
    "Enter new title" : "ໃສ່ຫົວຂໍ້ໃໝ່",
    "Select bookmark" : "ເລືອກບຸກມາກ",
    "You have never clicked this link" : "ທ່ານຍັງບໍ່ເຄີຍຄລິກລິ້ງນີ້ເທື່ອ",
    "You have clicked this link {count} times" : "ທ່ານໄດ້ຄລິກລິ້ງນີ້ {count} ຄັ້ງແລ້ວ",
    "Details" : "ລາຍລະອຽດ",
    "Rename" : "ປ່ຽນຊື່",
    "Copy link" : "ສຳເນົາລິ້ງ",
    "Move" : "ຍ້າຍ",
    "Add to folders" : "ເພີ່ມໃສ່ໂຟນເດີ",
    "Put bookmark into trash bin" : "ຍ້າຍບຸກມາກໄປທີ່ຖັງຂີ້ເຫຍື່ອ",
    "Restore bookmark" : "ກູ້ຄືນບຸກມາກ",
    "Delete bookmark permanently" : "ລຶບບຸກມາກຖາວອນ",
    "Content pending" : "ກຳລັງລໍຖ້າເນື້ອຫາ",
    "This content is being downloaded for offline use. Please check back later." : "ເນື້ອຫານີ້ກຳລັງຖືກດາວໂຫຼດເພື່ອໃຊ້ງານແບບອອບລາຍ. ກະລຸນາກັບມາເບິ່ງໃໝ່ພາຍຫຼັງ.",
    "Bookmarked {time} ago" : "ບຸກມາກເມື່ອ {time} ທີ່ແລ້ວ",
    "Bookmarked on {date}" : "ບຸກມາກເມື່ອ {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "ນີ້ແມ່ນລາຍການທີ່ທ່ານລຶບ. ລາຍການຕ່າງໆຈະຖືກລຶບຖາວອນຫຼັງຈາກສອງເດືອນ.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "ບຸກມາກຂອງໄຟລ໌ໃນເວັບ ເຊັ່ນ ຮູບພາບ ຫຼື PDF ຈະຖືກບັນທຶກໃສ່ໄຟລ໌ Nextcloud ຂອງທ່ານໂດຍອັດຕະໂນມັດ, ດັ່ງນັ້ນທ່ານຈຶ່ງຍັງສາມາດຊອກຫາພວກມັນໄດ້ເຖິງວ່າລິ້ງຈະໃຊ້ການບໍ່ໄດ້ແລ້ວກໍຕາມ.",
    "Searching in the current folder only." : "ກຳລັງຄົ້ນຫາໃນໂຟນເດີປັດຈຸບັນເທົ່ານັ້ນ.",
    "Repeat search in all folders" : "ຄົ້ນຫາຄືນໃໝ່ໃນທຸກໂຟນເດີ",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "ລິ້ງທີ່ບຸກມາກຈະຖືກກວດສອບເປັນປະຈຳ ແລະ ລິ້ງທີ່ເຂົ້າເຖິງບໍ່ໄດ້ຈະຖືກສະແດງຢູ່ທີ່ນີ້.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "ທ່ານສາມາດແບ່ງປັນໂຟນເດີບຸກມາກໃຫ້ຜູ້ອື່ນໄດ້. ທຸກໂຟນເດີທີ່ແບ່ງປັນໃຫ້ທ່ານຈະຖືກສະແດງຢູ່ທີ່ນີ້.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "ບຸກມາກອັນດຽວສາມາດຢູ່ໃນຫຼາຍໂຟນເດີພ້ອມກັນໄດ້. ການອັບເດດມັນຈະເປັນການອັບເດດທຸກໆບ່ອນ. ບຸກມາກທີ່ຊ້ຳກັນທັງໝົດຈະຖືກສະແດງຢູ່ທີ່ນີ້ເພື່ອຄວາມສະດວກ.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "ເລືອກແລ້ວ {folders} ໂຟນເດີ ແລະ {bookmarks} ບຸກມາກ",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["ເລືອກແລ້ວ %n ບຸກມາກ"],
    "_Selected %n folder_::_Selected %n folders_" : ["ເລືອກແລ້ວ %n ໂຟນເດີ"],
    "Do you really want to delete these items?" : "ທ່ານຕ້ອງການລຶບລາຍການເຫຼົ່ານີ້ແທ້ຫຼືບໍ່?",
    "Open all selected" : "ເປີດທັງໝົດທີ່ເລືອກ",
    "Move selection" : "ຍ້າຍລາຍການທີ່ເລືອກ",
    "Edit tags of selection" : "ແກ້ໄຂແທັກຂອງລາຍການທີ່ເລືອກ",
    "Delete selection" : "ລຶບລາຍການທີ່ເລືອກ",
    "Select all" : "ເລືອກທັງໝົດ",
    "Cancel selection" : "ຍົກເລີກການເລືອກ",
    "Sort by created date" : "ຈັດລຽງຕາມວັນທີສ້າງ",
    "Sort by last modified" : "ຈັດລຽງຕາມການແກ້ໄຂຫຼ້າສຸດ",
    "Sort by title" : "ຈັດລຽງຕາມຫົວຂໍ້",
    "Sort by click count" : "ຈັດລຽງຕາມຈຳນວນການຄລິກ",
    "Sort by manual order" : "ຈັດລຽງດ້ວຍຕົນເອງ",
    "Sort by URL" : "ຈັດລຽງຕາມ URL",
    "RSS feed copied" : "ສຳເນົາ RSS feed ແລ້ວ",
    "Trash Bin" : "ຖັງຂີ້ເຫຍື່ອ",
    "Go back" : "ກັບຄືນ",
    "Share folder" : "ແບ່ງປັນໂຟນເດີ",
    "Open folder details" : "ເປີດລາຍລະອຽດໂຟນເດີ",
    "Select one or more tags" : "ເລືອກໜຶ່ງ ຫຼື ຫຼາຍແທັກ",
    "New" : "ໃໝ່",
    "New bookmark" : "ບຸກມາກໃໝ່",
    "New folder" : "ໂຟນເດີໃໝ່",
    "Change to grid view" : "ປ່ຽນເປັນມຸມມອງຕາຕະລາງ",
    "Change to list view" : "ປ່ຽນເປັນມຸມມອງລາຍການ",
    "Copy RSS Feed of current view" : "ສຳເນົາ RSS Feed ຂອງມຸມມອງປັດຈຸບັນ",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS feed ຕ້ອງການການຢືນຢັນຕົວຕົນດ້ວຍບັນຊີ Nextcloud ຂອງທ່ານ",
    "Search" : "ຄົ້ນຫາ",
    "Empty trash bin" : "ລ້າງຖັງຂີ້ເຫຍື່ອ",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["ກຳລັງເພີ່ມ %n ບຸກມາກ ໃສ່ໂຟນເດີໃໝ່"],
    "Enter a link" : "ໃສ່ລິ້ງ",
    "Enter a title" : "ໃສ່ຫົວຂໍ້",
    "No bookmarks found" : "ບໍ່ພົບບຸກມາກ",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} ໂຟນເດີ ແລະ {bookmarks} ບຸກມາກ",
    "_%n bookmark_::_%n bookmarks_" : ["%n ບຸກມາກ"],
    "_%n folder_::_%n folders_" : ["%n ໂຟນເດີ"],
    "Welcome to Bookmarks" : "ຍິນດີຕ້ອນຮັບສູ່ ບຸກມາກ",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "ແອັບນີ້ຊ່ວຍໃຫ້ທ່ານຈັດການລິ້ງໄປຫາເວັບໄຊທີ່ທ່ານມັກ. ຈັດຮຽງບຸກມາກຂອງທ່ານໃສ່ໃນໂຟນເດີ, ຕິດແທັກ ແລະ ແບ່ງປັນໃຫ້ຜູ້ອື່ນ! ແອັບຈະກວດສອບການເຂົ້າເຖິງຂອງລິ້ງທັງໝົດເປັນປະຈຳ ແລະ ສະແດງລິ້ງທີ່ໃຊ້ການບໍ່ໄດ້. ຖ້າທ່ານເພີ່ມລິ້ງຂອງໄຟລ໌ໃນເວັບ, ໄຟລ໌ນັ້ນຈະຖືກດາວໂຫຼດໃສ່ Nextcloud Files ຂອງທ່ານໂດຍອັດຕະໂນມັດ. ທ່ານຍັງສາມາດນຳເຂົ້າບຸກມາກຈາກບໍລິການອື່ນ ຫຼື ຊິ້ງຄ໌ບຸກມາກຈາກທຸກບຣາວເຊີຂອງທ່ານໂດຍກົງກັບແອັບນີ້.",
    "Add a bookmark" : "ເພີ່ມບຸກມາກ",
    "Import bookmarks" : "ນຳເຂົ້າບຸກມາກ",
    "Sync with your browser" : "ຊິ້ງຄ໌ກັບບຣາວເຊີຂອງທ່ານ",
    "Do you really want to permanently delete this folder?" : "ທ່ານຕ້ອງການລຶບໂຟນເດີນີ້ຖາວອນແທ້ຫຼືບໍ່?",
    "Select folder" : "ເລືອກໂຟນເດີ",
    "Enter folder title" : "ໃສ່ຊື່ໂຟນເດີ",
    "Shared by {user}" : "ແບ່ງປັນໂດຍ {user}",
    "Rename folder" : "ປ່ຽນຊື່ໂຟນເດີ",
    "Move folder" : "ຍ້າຍໂຟນເດີ",
    "Put folder into trashbin" : "ຍ້າຍໂຟນເດີໄປທີ່ຖັງຂີ້ເຫຍື່ອ",
    "Restore folder" : "ກູ້ຄືນໂຟນເດີ",
    "Delete folder permanently" : "ລຶບໂຟນເດີຖາວອນ",
    "Choose folder" : "ເລືອກໂຟນເດີ",
    "Submit" : "ຕົກລົງ",
    "Cancel" : "ຍົກເລີກ",
    "Deleting bookmarks" : "ກຳລັງລຶບບຸກມາກ",
    "Deleting selection" : "ກຳລັງລຶບລາຍການທີ່ເລືອກ",
    "Importing bookmarks" : "ກຳລັງນຳເຂົ້າບຸກມາກ",
    "Moving selection" : "ກຳລັງຍ້າຍລາຍການທີ່ເລືອກ",
    "Adding selection to folders" : "ກຳລັງເພີ່ມລາຍການທີ່ເລືອກໃສ່ໂຟນເດີ",
    "Emptying trashbin" : "ກຳລັງລ້າງຖັງຂີ້ເຫຍື່ອ",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["ກຳລັງຍ້າຍ %n ໂຟນເດີ ແລະ ບາງບຸກມາກ"],
    "_Moving %n folder_::_Moving %n folders_" : ["ກຳລັງຍ້າຍ %n ໂຟນເດີ"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["ກຳລັງຍ້າຍ %n ບຸກມາກ"],
    "All bookmarks" : "ບຸກມາກທັງໝົດ",
    "Recent" : "ຫວ່າງບໍ່ດົນມານີ້",
    "Frequently clicked" : "ຄລິກເລື້ອຍໆ",
    "Shared with you" : "ແບ່ງປັນກັບທ່ານ",
    "Files" : "ໄຟລ໌",
    "Duplicates" : "ລາຍການທີ່ຊ້ຳກັນ",
    "Broken links" : "ລິ້ງທີ່ໃຊ້ການບໍ່ໄດ້",
    "New tag" : "ແທັກໃໝ່",
    "Search tags" : "ຄົ້ນຫາແທັກ",
    "Delete" : "ລຶບ",
    "Untagged" : "ບໍ່ມີແທັກ",
    "{used} bookmarks of {available} available" : "ໃຊ້ໄປແລ້ວ {used} ບຸກມາກ ຈາກທັງໝົດ {available}",
    "Bookmarks Settings" : "ການຕັ້ງຄ່າບຸກມາກ",
    "No bookmarked files" : "ບໍ່ມີໄຟລ໌ທີ່ບຸກມາກໄວ້",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "ບຸກມາກຂອງໄຟລ໌ ເຊັ່ນ ຮູບພາບ ຫຼື PDF ຈະຖືກບັນທຶກໃສ່ໄຟລ໌ Nextcloud ຂອງທ່ານໂດຍອັດຕະໂນມັດ, ດັ່ງນັ້ນທ່ານຈຶ່ງຍັງສາມາດຊອກຫາພວກມັນໄດ້ເຖິງວ່າລິ້ງຈະໃຊ້ການບໍ່ໄດ້ແລ້ວກໍຕາມ.",
    "Nothing found" : "ບໍ່ພົບຫຍັງເລີຍ",
    "Your search yielded no results in the current folder." : "ການຄົ້ນຫາຂອງທ່ານບໍ່ພົບຜົນລັບໃນໂຟນເດີປັດຈຸບັນ.",
    "No broken links" : "ບໍ່ມີລິ້ງທີ່ໃຊ້ການບໍ່ໄດ້",
    "No shared folders" : "ບໍ່ມີໂຟນເດີທີ່ແບ່ງປັນ",
    "No duplicated bookmarks" : "ບໍ່ມີບຸກມາກທີ່ຊ້ຳກັນ",
    "No deleted bookmarks" : "ບໍ່ມີບຸກມາກທີ່ຖືກລຶບ",
    "You haven't deleted anything yet." : "ທ່ານຍັງບໍ່ທັນໄດ້ລຶບຫຍັງເລີຍ.",
    "No bookmarks here" : "ບໍ່ມີບຸກມາກຢູ່ທີ່ນີ້",
    "Add bookmarks manually or import bookmarks from a HTML file." : "ເພີ່ມບຸກມາກດ້ວຍຕົນເອງ ຫຼື ນຳເຂົ້າບຸກມາກຈາກໄຟລ໌ HTML.",
    "Archive path" : "ເສັ້ນທາງບ່ອນເກັບຖາວອນ",
    "Backup path" : "ເສັ້ນທາງບ່ອນສຳຮອງຂໍ້ມູນ",
    "Please select \"Add to home screen\" in your browser menu" : "ກະລຸນາເລືອກ \"ເພີ່ມໃສ່ໜ້າຈໍຫຼັກ\" ໃນເມນູບຣາວເຊີຂອງທ່ານ",
    "Bookmarks settings" : "ການຕັ້ງຄ່າບຸກມາກ",
    "Import/Export" : "ນຳເຂົ້າ/ສົ່ງອອກ",
    "Export bookmarks" : "ສົ່ງອອກບຸກມາກ",
    "Auto-archiving" : "ການເກັບຖາວອນອັດຕະໂນມັດ",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "ແອັບບຸກມາກສາມາດເກັບເນື້ອຫາເວັບຂອງລິ້ງທີ່ທ່ານບຸກມາກໄວ້ແບບອັດຕະໂນມັດ",
    "Enable archiving" : "ເປີດໃຊ້ການເກັບຖາວອນ",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "ໃສ່ເສັ້ນທາງໂຟນເດີໃນໄຟລ໌ຂອງທ່ານເພື່ອໃຊ້ເປັນບ່ອນເກັບໄຟລ໌ທີ່ບຸກມາກໄວ້.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "ໃນປັດຈຸບັນ ຜູ້ດູແລລະບົບຂອງທ່ານໄດ້ປິດການເຂົ້າເຖິງເຄືອຂ່າຍສຳລັບແອັບນີ້, ນັ້ນແມ່ນເຫດຜົນທີ່ການເກັບຖາວອນອັດຕະໂນມັດຖືກປິດໄວ້ໃນຕອນນີ້.",
    "Auto-Backup" : "ສຳຮອງຂໍ້ມູນອັດຕະໂນມັດ",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "ແອັບບຸກມາກສາມາດສຳຮອງຂໍ້ມູນບຸກມາກຂອງທ່ານທຸກມື້ແບບອັດຕະໂນມັດ ເພື່ອປ້ອງກັນຂໍ້ມູນເສຍຫາຍເມື່ອມີການຊິ້ງຄ໌ບຸກມາກຂ້າມອຸປະກອນ.",
    "Enable backups" : "ເປີດໃຊ້ການສຳຮອງຂໍ້ມູນ",
    "Enter the path of a folder in your Files where backups will be stored." : "ໃສ່ເສັ້ນທາງໂຟນເດີໃນໄຟລ໌ຂອງທ່ານເພື່ອໃຊ້ເປັນບ່ອນເກັບຂໍ້ມູນສຳຮອງ.",
    "Context Chat integration" : "ການເຊື່ອມຕໍ່ກັບ Context Chat",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "ແອັບບຸກມາກສາມາດສົ່ງເນື້ອຫາຕົວອັກສອນຂອງເວັບໄຊທີ່ທ່ານບຸກມາກໃຫ້ກັບ Context Chat ໂດຍອັດຕະໂນມັດ, ເຊິ່ງຊ່ວຍໃຫ້ທ່ານສາມາດຖາມຄຳຖາມ ແລະ ຮັບຄຳຕອບໂດຍອີງຕາມເນື້ອຫາເຫຼົ່ານັ້ນໄດ້. ຟີເຈີນີ້ຈະໃຊ້ໄດ້ກໍຕໍ່ເມື່ອເປີດໃຊ້ການເກັບຖາວອນອັດຕະໂນມັດແລ້ວເທົ່ານັ້ນ.",
    "Context chat is currently not installed, but is required for this feature." : "Context chat ຍັງບໍ່ທັນໄດ້ຕິດຕັ້ງເທື່ອ, ເຊິ່ງຈຳເປັນຕ້ອງມີສຳລັບຟີເຈີນີ້.",
    "Enable Context Chat integration" : "ເປີດໃຊ້ການເຊື່ອມຕໍ່ກັບ Context Chat",
    "Client apps" : "ແອັບລູກຂ່າຍ",
    "Also check out the collection of client apps that integrate with this app: " : "ລອງເບິ່ງແອັບລູກຂ່າຍຕ່າງໆທີ່ສາມາດເຊື່ອມຕໍ່ກັບແອັບນີ້ໄດ້: ",
    "Install web app" : "ຕິດຕັ້ງເວັບແອັບ",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "ທ່ານສາມາດຕິດຕັ້ງແອັບນີ້ໄວ້ທີ່ໜ້າຈໍຫຼັກຂອງອຸປະກອນເພື່ອເຂົ້າເຖິງບຸກມາກໃນໂທລະສັບຂອງທ່ານໄດ້ໄວຂຶ້ນ. ທ່ານສາມາດລຶບແອັບອອກຈາກໜ້າຈໍຫຼັກໄດ້ທຸກເວລາຖ້າບໍ່ຕ້ອງການ.",
    "Install on home screen" : "ຕິດຕັ້ງໃສ່ໜ້າຈໍຫຼັກ",
    "Bookmarklet" : "ບຸກມາກເລັດ (Bookmarklet)",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "ລາກສິ່ງນີ້ໄປທີ່ແຖບບຸກມາກຂອງບຣາວເຊີຂອງທ່ານ ແລະ ຄລິກມັນເພື່ອບຸກມາກເວັບໄຊໄດ້ຢ່າງວ່ອງໄວ.",
    "Add to {instanceName}" : "ເພີ່ມໃສ່ {instanceName}",
    "Need help?" : "ຕ້ອງການຄວາມຊ່ວຍເຫຼືອ?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "ຖ້າທ່ານມີບັນຫາກັບແອັບບຸກມາກ ຫຼື ມີໄອເດຍເພື່ອປັບປຸງໃຫ້ດີຂຶ້ນ, ຢ່າລັງເລທີ່ຈະຕິດຕໍ່ຫາພວກເຮົາໂດຍການຄລິກບ່ອນນີ້.",
    "Support this project" : "ສະໜັບສະໜູນໂຄງການນີ້",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "ການພັດທະນາແອັບບຸກມາກຂອງຂ້ອຍແມ່ນໄດ້ຮັບການສະໜັບສະໜູນຈາກຮູບແບບການສະໝັກສະມາຊິກແບບສະໝັກໃຈ. ຖ້າທ່ານເຫັນວ່າສິ່ງທີ່ຂ້ອຍເຮັດມີປະໂຫຍດ, ຂ້ອຍຈະດີໃຈຫຼາຍຖ້າທ່ານສາມາດສະໜັບສະໜູນຜົນງານຂອງຂ້ອຍໄດ້. ນອກຈາກນັ້ນ, ກະລຸນາຊ່ວຍຣີວິວແອັບໃນ Nextcloud app store ນຳ. ຂອບໃຈ 💙",
    "Created {time} ago" : "ສ້າງເມື່ອ {time} ທີ່ແລ້ວ",
    "Created on {date}" : "ສ້າງເມື່ອ {date}",
    "(Empty title)" : "(ບໍ່ມີຫົວຂໍ້)",
    "Title" : "ຫົວຂໍ້",
    "Link" : "ລິ້ງ",
    "Untitled folder" : "ໂຟນເດີບໍ່ມີຊື່",
    "Root folder" : "ໂຟນເດີຫຼັກ (Root folder)",
    "Tags" : "ແທັກ",
    "Select tags and create new ones" : "ເລືອກແທັກ ຫຼື ສ້າງແທັກໃໝ່",
    "Notes" : "ບັນທຶກ",
    "Notes for this bookmark …" : "ບັນທຶກສຳລັບບຸກມາກນີ້...",
    "Archived file" : "ໄຟລ໌ທີ່ເກັບຖາວອນ",
    "Open file" : "ເປີດໄຟລ໌",
    "Download file" : "ດາວໂຫຼດໄຟລ໌",
    "Open file location" : "ເປີດບ່ອນເກັບໄຟລ໌",
    "Link copied" : "ສຳເນົາລິ້ງແລ້ວ",
    "Owner" : "ເຈົ້າຂອງ",
    "Sharing" : "ການແບ່ງປັນ",
    "Select a user or group" : "ເລືອກຜູ້ໃຊ້ ຫຼື ກຸ່ມ",
    "Share link" : "ແບ່ງປັນລິ້ງ",
    "Reading allowed" : "ອະນຸຍາດໃຫ້ອ່ານ",
    "Copy RSS feed" : "ສຳເນົາ RSS feed",
    "Delete link" : "ລຶບລິ້ງ",
    "Create public link" : "ສ້າງລິ້ງສາທາລະນະ",
    "Resharing allowed" : "ອະນຸຍາດໃຫ້ແບ່ງປັນຕໍ່",
    "Editing allowed" : "ອະນຸຍາດໃຫ້ແກ້ໄຂ",
    "Allow editing" : "ອະນຸຍາດໃຫ້ແກ້ໄຂ",
    "Allow resharing" : "ອະນຸຍາດໃຫ້ແບ່ງປັນຕໍ່",
    "Remove share" : "ຍົກເລີກການແບ່ງປັນ",
    "Would you like to support this project?" : "ທ່ານຕ້ອງການສະໜັບສະໜູນໂຄງການນີ້ຫຼືບໍ່?",
    "Leave a rating on the Nextcloud App Store" : "ໃຫ້ຄະແນນໃນ Nextcloud App Store",
    "Failed to save settings" : "ບັນທຶກການຕັ້ງຄ່າບໍ່ສຳເລັດ",
    "Failed to load settings" : "ໂຫຼດການຕັ້ງຄ່າບໍ່ສຳເລັດ",
    "Privacy" : "ຄວາມເປັນສ່ວນຕົວ",
    "The app will try to access web pages that you add to automatically add information about them." : "ແອັບຈະພະຍາຍາມເຂົ້າເຖິງເວັບໄຊທີ່ທ່ານເພີ່ມ ເພື່ອເພີ່ມຂໍ້ມູນກ່ຽວກັບເວັບໄຊນັ້ນໂດຍອັດຕະໂນມັດ.",
    "Enable accessing and collecting information from the web pages you add" : "ເປີດໃຊ້ການເຂົ້າເຖິງ ແລະ ຮວບຮວມຂໍ້ມູນຈາກເວັບໄຊທີ່ທ່ານເພີ່ມ",
    "Performance" : "ປະສິດທິພາບ",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "ໃນລະບົບທີ່ມີຜູ້ໃຊ້ຈຳນວນຫຼາຍ, ອາດຈະມີປະໂຫຍດຖ້າຈຳກັດຈຳນວນບຸກມາກຕໍ່ແຕ່ລະບັນຊີ.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "ຈຳນວນບຸກມາກສູງສຸດທີ່ອະນຸຍາດຕໍ່ບັນຊີ. (0 ໝາຍເຖິງບໍ່ຈຳກັດ; ຄ່າເລີ່ມຕົ້ນແມ່ນບໍ່ຈຳກັດ)",
    "Previews" : "ຕົວຢ່າງມຸມມອງ",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "ເພື່ອສະແດງພາບໜ້າຈໍແທ້ຂອງເວັບໄຊທີ່ທ່ານບຸກມາກ, ແອັບສາມາດໃຊ້ບໍລິການຈາກພາຍນອກເພື່ອສ້າງຕົວຢ່າງມຸມມອງໄດ້.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "ທ່ານສາມາດສະໝັກໃຊ້ຟຣີໄດ້ທີ່ screeenly.com ຫຼື ຕັ້ງຄ່າເຊີບເວີຂອງທ່ານເອງ.",
    "Screeenly API URL" : "Screeenly API URL",
    "Screeenly API key" : "Screeenly API key",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine API key",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot API URL",
    "Generic screenshot API" : "Generic screenshot API",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "ສະໝັກໃຊ້ກັບຜູ້ໃຫ້ບໍລິການ screenshot API ແລະ ໃສ່ API URL ໄວ້ທາງລຸ່ມ. ໃຊ້ຕົວປ່ຽນ {url} ເປັນຕົວແທນສຳລັບ URL ທີ່ຈະແຄັບພາບ. API ຕ້ອງສົ່ງຄືນສະເພາະຮູບພາບໂດຍກົງເທົ່ານັ້ນ.",
    "Generic API URL" : "Generic API URL",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "ພຽງແຕ່ຕິດຕັ້ງ Pageres CLI ໂດຍ Sindre Sorhus ໃນເຊີບເວີຂອງທ່ານ ແລະ ແອັບບຸກມາກຈະຊອກຫາມັນເອງ. ທ່ານຍັງສາມາດເພີ່ມ ENV vars ເພີ່ມເຕີມເພື່ອໃຊ້ກັບ pageres ໄດ້ ເຊັ່ນ:",
    "Pageres ENV variables" : "Pageres ENV variables",
    "This URL is already bookmarked! Overwrite?" : "URL ນີ້ຖືກບຸກມາກໄວ້ແລ້ວ! ຕ້ອງການຂຽນທັບຫຼືບໍ່?",
    "Enter bookmark title" : "ໃສ່ຊື່ບຸກມາກ",
    "Enter bookmark URL" : "ໃສ່ URL ບຸກມາກ",
    "Folder" : "ໂຟນເດີ",
    "Root Folder" : "ໂຟນເດີຫຼັກ",
    "Save" : "ບັນທຶກ",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "ການເຂົ້າເຖິງເຄືອຂ່າຍຖືກປິດໄວ້ເປັນຄ່າເລີ່ມຕົ້ນ. ໄປທີ່ການຕັ້ງຄ່າຜູ້ດູແລລະບົບສຳລັບແອັບບຸກມາກ ເພື່ອອະນຸຍາດໃຫ້ດຶງຂໍ້ມູນຕົວຢ່າງມຸມມອງ ແລະ ໄອຄອນເວັບໄຊ.",
    "What's new?" : "ມີຫຍັງໃໝ່?",
    "What" : "ແມ່ນຫຍັງ",
    "Failed to count unavailable bookmarks" : "ນັບຈຳນວນບຸກມາກທີ່ເຂົ້າເຖິງບໍ່ໄດ້ບໍ່ສຳເລັດ",
    "Failed to count archived bookmarks" : "ນັບຈຳນວນບຸກມາກທີ່ເກັບຖາວອນບໍ່ສຳເລັດ",
    "Failed to count deleted bookmarks" : "ນັບຈຳນວນບຸກມາກທີ່ຖືກລຶບບໍ່ສຳເລັດ",
    "Failed to count duplicated bookmarks" : "ນັບຈຳນວນບຸກມາກທີ່ຊ້ຳກັນບໍ່ສຳເລັດ",
    "Failed to count bookmarks" : "ນັບຈຳນວນບຸກມາກບໍ່ສຳເລັດ",
    "Failed to load bookmark" : "ໂຫຼດບຸກມາກບໍ່ສຳເລັດ",
    "Failed to find existing bookmark" : "ຊອກຫາບຸກມາກທີ່ມີຢູ່ບໍ່ສຳເລັດ",
    "Failed to create bookmark" : "ສ້າງບຸກມາກບໍ່ສຳເລັດ",
    "Failed to save bookmark" : "ບັນທຶກບຸກມາກບໍ່ສຳເລັດ",
    "Failed to move bookmark" : "ຍ້າຍບຸກມາກບໍ່ສຳເລັດ",
    "Failed to copy bookmark" : "ສຳເນົາບຸກມາກບໍ່ສຳເລັດ",
    "Failed to delete bookmark" : "ລຶບບຸກມາກບໍ່ສຳເລັດ",
    "Failed to restore bookmark" : "ກູ້ຄືນບຸກມາກບໍ່ສຳເລັດ",
    "Import successful" : "ນຳເຂົ້າສຳເລັດແລ້ວ",
    "Failed to rename tag" : "ປ່ຽນຊື່ແທັກບໍ່ສຳເລັດ",
    "Failed to load tags" : "ໂຫຼດແທັກບໍ່ສຳເລັດ",
    "Failed to load folders" : "ໂຫຼດໂຟນເດີບໍ່ສຳເລັດ",
    "Failed to load deleted folders" : "ໂຫຼດໂຟນເດີທີ່ຖືກລຶບບໍ່ສຳເລັດ",
    "Failed to load deleted bookmarks" : "ໂຫຼດບຸກມາກທີ່ຖືກລຶບບໍ່ສຳເລັດ",
    "Failed to delete folder" : "ລຶບໂຟນເດີບໍ່ສຳເລັດ",
    "Failed to move folder" : "ຍ້າຍໂຟນເດີບໍ່ສຳເລັດ",
    "Failed to restore folder" : "ກູ້ຄືນໂຟນເດີບໍ່ສຳເລັດ",
    "Failed to create folder" : "ສ້າງໂຟນເດີບໍ່ສຳເລັດ",
    "Failed to load children order" : "ໂຫຼດລຳດັບລາຍການຍ່ອຍບໍ່ສຳເລັດ",
    "Failed to move parts of selection" : "ຍ້າຍບາງສ່ວນຂອງລາຍການທີ່ເລືອກບໍ່ສຳເລັດ",
    "Failed to copy parts of selection" : "ສຳເນົາບາງສ່ວນຂອງລາຍການທີ່ເລືອກບໍ່ສຳເລັດ",
    "Failed to delete parts of selection" : "ລຶບບາງສ່ວນຂອງລາຍການທີ່ເລືອກບໍ່ສຳເລັດ",
    "Failed to tag parts of selection" : "ຕິດແທັກບາງສ່ວນຂອງລາຍການທີ່ເລືອກບໍ່ສຳເລັດ",
    "Failed to fetch bookmarks." : "ດຶງຂໍ້ມູນບຸກມາກບໍ່ສຳເລັດ.",
    "Failed to store setting" : "ບັນທຶກການຕັ້ງຄ່າບໍ່ສຳເລັດ",
    "Failed to load setting {key}" : "ໂຫຼດການຕັ້ງຄ່າ {key} ບໍ່ສຳເລັດ",
    "Failed to create share for folder {folderId}" : "ສ້າງການແບ່ງປັນສຳລັບໂຟນເດີ {folderId} ບໍ່ສຳເລັດ",
    "Failed to update share {shareId}" : "ອັບເດດການແບ່ງປັນ {shareId} ບໍ່ສຳເລັດ",
    "Failed to delete share {shareId}" : "ລຶບການແບ່ງປັນ {shareId} ບໍ່ສຳເລັດ",
    "Failed to create public link for folder {folderId}" : "ສ້າງລິ້ງສາທາລະນະສຳລັບໂຟນເດີ {folderId} ບໍ່ສຳເລັດ",
    "Failed to delete public link for folder {folderId}" : "ລຶບລິ້ງສາທາລະນະສຳລັບໂຟນເດີ {folderId} ບໍ່ສຳເລັດ",
    "Failed to permanently delete parts of trash bin" : "ລຶບບາງສ່ວນໃນຖັງຂີ້ເຫຍື່ອແບບຖາວອນບໍ່ສຳເລັດ",
    "Create bookmarks for mentioned links" : "ສ້າງບຸກມາກສຳລັບລິ້ງທີ່ຖືກກ່າວເຖິງ",
    "No links found in this message" : "ບໍ່ພົບລິ້ງໃນຂໍ້ຄວາມນີ້",
    "Bookmarks feed" : "ຟີດບຸກມາກ (Bookmarks feed)"
},
"nplurals=1; plural=0;");
