OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Bokmärken",
    "You bookmarked \"%s\"" : "Du sparade \"%s\"",
    "%1$s bookmarked \"%2$s\"" : "%1$s sparade \"%2$s\"",
    "Someone bookmarked \"%s\"" : "Någon sparade ”%s”",
    "You deleted \"%s\"" : "Du raderade \"%s\"",
    "%1$s deleted \"%2$s\"" : "%1$s raderade \"%2$s\"",
    "Someone deleted \"%s\"" : "Någon raderade \"%s\"",
    "You created folder \"%s\"" : "Du skapade mappen \"%s\"",
    "%1$s created folder \"%2$s\"" : "%1$s skapade mappen \"%2$s\"",
    "Someone created folder \"%s\"" : "Någon skapade mappen \"%s\"",
    "You moved folder \"%s\"" : "Du flyttade mappen \"%s\"",
    "%1$s moved folder \"%2$s\"" : "%1$s flyttade mappen \"%2$s\"",
    "Someone moved folder \"%s\"" : "Någon flyttade mappen \"%s\"",
    "You deleted folder \"%s\"" : "Du raderade mappen \"%s\"",
    "%1$s deleted folder \"%2$s\"" : "%1$s raderade mappen \"%2$s\"",
    "Someone deleted folder \"%s\"" : "Någon raderade mappen \"%s\"",
    "You shared folder \"%1$s\" with %2$s" : "Du delade mappen \"%1$s\" med %2$s",
    "You shared folder \"%s\" with someone" : "Du delade mappen \"%s\" med någon",
    "%1$s shared folder \"%2$s\" with you" : "%1$s delade mappen \"%2$s\" med dig",
    "Someone shared folder \"%s\" with you" : "Någon delade mappen \"%s\" med dig",
    "You unshared folder \"%1$s\" with %2$s" : "Du slutade dela mappen \"%1$s\" med %2$s",
    "You unshared folder \"%s\" with someone" : "Du slutade dela mappen \"%s\" med någon",
    "%1$s unshared folder \"%2$s\" with you" : "%1$s slutade dela mappen \"%2$s\" med dig",
    "Someone unshared folder \"%s\" with you" : "Någon slutade dela mappen ”%s” med dig",
    "No file provided for import" : "Ingen fil angavs för import",
    "Failed to upload file" : "Det gick inte att ladda upp filen",
    "Unsupported file type for import: " : "Filtypen stöds inte för import: ",
    "Bookmarks shared by %s" : "Bokmärken delade av %s",
    "Frequent bookmarks" : "Vanliga bokmärken",
    "Recent bookmarks" : "Senaste bokmärken",
    "Bookmark" : "Bokmärke",
    "Bookmark deleted" : "Bokmärket har tagits bort",
    "Bookmark created" : "Bokmärket har skapats",
    "Bookmark moved" : "Bokmärket har flyttats",
    "Bookmark updated" : "Bokmärket har uppdaterats",
    "Create bookmark" : "Skapa bokmärke",
    "Takes a link and adds it to your collection of bookmarks." : "Tar en länk och lägger till den i dina bokmärken.",
    "Bookmarks Backups" : "Säkerhetskopior av bokmärken",
    "Collect and manage bookmarks, synced with all your devices" : "Samla och hantera bokmärken, synkroniserade med alla dina enheter",
    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- ☠ Find broken links and duplicates\n- 📲 Synchronize with all your browsers and devices\n- 📔 Store archived versions of your links in case they are depublished\n- 🔍 Full-text search on site contents\n- 👪 Share bookmarks with other users, groups and teams or via public links\n- ⚛ Generate RSS feeds of your collections\n- 📈 Stats on how often you access which links\n- 🔒 Automatic backups of your bookmarks collection\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 Sortera bokmärken i mappar\n- 🏷 Lägg till taggar och personliga anteckningar\n- ☠ Hitta trasiga länkar och dubbletter\n- 📲 Synkronisera med alla dina webbläsare och enheter\n- 📔 Spara arkiverade versioner av dina länkar om de avpubliceras\n- 🔍 Fulltextsök i webbplatsinnehåll\n- 👪 Dela bokmärken med andra användare, grupper och team eller via publika länkar\n- ⚛ Skapa RSS-flöden av dina samlingar\n- 📈 Visa statistik över hur ofta du öppnar olika länkar\n- 🔒 Säkerhetskopiera bokmärkessamlingen automatiskt\n- 💼 Inbyggda widgetar för instrumentpanelen med ofta använda och senaste länkar\n\nKrav:\n - PHP-tillägg:\n   - intl: *\n   - mbstring: *\n - om MySQL används krävs minst version 8.0",
    "Do you really want to delete this bookmark?" : "Vill du verkligen ta bort det här bokmärket?",
    "Link copied to clipboard" : "Länken har kopierats till urklipp",
    "Enter new title" : "Ange ny titel",
    "Select bookmark" : "Välj bokmärke",
    "You have never clicked this link" : "Du har aldrig klickat på den här länken",
    "You have clicked this link {count} times" : "Du har klickat på den här länken {count} gånger",
    "Details" : "Detaljer",
    "Rename" : "Byt namn",
    "Copy link" : "Kopiera länk",
    "Move" : "Flytta",
    "Add to folders" : "Lägg till i mappar",
    "Put bookmark into trash bin" : "Lägg bokmärket i papperskorgen",
    "Restore bookmark" : "Återställ bokmärket",
    "Delete bookmark permanently" : "Ta bort bokmärket permanent",
    "Content pending" : "Väntar på innehåll",
    "This content is being downloaded for offline use. Please check back later." : "Innehållet hämtas för användning offline. Försök igen senare.",
    "Bookmarked {time} ago" : "Sparad för {time} sedan",
    "Bookmarked on {date}" : "Sparad den {date}",
    "These are your deleted items. Items will be deleted permanently after two months." : "Det här är dina raderade objekt. Objekt kommer att raderas permanent efter två månader.",
    "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer på webben som foton eller PDF-filer sparas automatiskt till dina Nextcloud-filer, så att du fortfarande kan hitta dem även när länken går offline.",
    "Searching in the current folder only." : "Söker endast i den aktuella mappen.",
    "Repeat search in all folders" : "Upprepa sökning i alla mappar",
    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Bokmärkta länkar kontrolleras regelbundet och de som inte kan nås listas här.",
    "You can share bookmark folders with others. All folders shared with you are listed here." : "Du kan dela bokmärkesmappar med andra. Alla mappar som delas med dig listas här.",
    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Ett bokmärke kan finnas i flera mappar samtidigt. Om det uppdateras, uppdateras alla kopior. Alla dubbletter listas här för enkel åtkomst.",
    "Selected {folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken har valts",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valde %n bokmärke","Valde %n bokmärken"],
    "_Selected %n folder_::_Selected %n folders_" : ["Valde %n mapp","Valde %n mappar"],
    "Do you really want to delete these items?" : "Vill du verkligen ta bort de här objekten?",
    "Open all selected" : "Öppna alla markerade",
    "Move selection" : "Flytta urval",
    "Edit tags of selection" : "Ändra taggar för urval",
    "Delete selection" : "Ta bort urval",
    "Select all" : "Välj alla",
    "Cancel selection" : "Avbryt markering",
    "Sort by created date" : "Sortera efter skapandedatum",
    "Sort by last modified" : "Sortera efter senaste ändring",
    "Sort by title" : "Sortera efter titel",
    "Sort by click count" : "Sortera efter antal klick",
    "Sort by manual order" : "Sortera efter manuell ordning",
    "Sort by URL" : "Sortera efter URL",
    "RSS feed copied" : "RSS-flödet har kopierats",
    "Trash Bin" : "Papperskorg",
    "Go back" : "Gå tillbaka",
    "Share folder" : "Dela mapp",
    "Open folder details" : "Öppna mappinformation",
    "Select one or more tags" : "Välj en eller flera taggar",
    "New" : "Nytt",
    "New bookmark" : "Nytt bokmärke",
    "New folder" : "Ny mapp",
    "Change to grid view" : "Växla till rutnätsvy",
    "Change to list view" : "Växla till listvy",
    "Copy RSS Feed of current view" : "Kopiera RSS-flödet för den aktuella vyn",
    "The RSS feed requires authentication with your Nextcloud credentials" : "RSS-flödet kräver autentisering med dina Nextcloud-uppgifter",
    "Search" : "Sök",
    "Empty trash bin" : "Töm papperskorgen",
    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lägger till %n bokmärke i ny mapp","Lägger till %n bokmärken i ny mapp"],
    "Enter a link" : "Ange en länk",
    "Enter a title" : "Ange en titel",
    "No bookmarks found" : "Inga bokmärken hittades",
    "{folders} folders and {bookmarks} bookmarks" : "{folders} mappar och {bookmarks} bokmärken",
    "_%n bookmark_::_%n bookmarks_" : ["%n bokmärke","%n bokmärken"],
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "Welcome to Bookmarks" : "Välkommen till Bokmärken",
    "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Med den här appen kan du hantera länkar till dina favoritplatser på webben. Sortera bokmärkena i mappar, märk dem med taggar och dela dem med andra. Appen kontrollerar regelbundet om länkarna är tillgängliga och visar länkar som inte kan nås. Om du lägger till en länk till en fil på webben hämtas filen automatiskt till Nextcloud Filer. Du kan även importera bokmärken från andra tjänster eller synkronisera bokmärken direkt från alla dina webbläsare.",
    "Add a bookmark" : "Lägg till ett bokmärke",
    "Import bookmarks" : "Importera bokmärken",
    "Sync with your browser" : "Synkronisera med din webbläsare",
    "Do you really want to permanently delete this folder?" : "Vill du verkligen ta bort den här mappen permanent?",
    "Select folder" : "Välj mapp",
    "Enter folder title" : "Ange titel",
    "Shared by {user}" : "Delad av {user}",
    "Rename folder" : "Byt namn på mapp",
    "Move folder" : "Flytta mapp",
    "Put folder into trashbin" : "Lägg mappen i papperskorgen",
    "Restore folder" : "Återställ mapp",
    "Delete folder permanently" : "Ta bort mapp permanent",
    "Choose folder" : "Välj mapp",
    "Submit" : "Skicka",
    "Cancel" : "Avbryt",
    "Deleting bookmarks" : "Tar bort bokmärken",
    "Deleting selection" : "Tar bort urval",
    "Importing bookmarks" : "Importerar bokmärken",
    "Moving selection" : "Flyttar urval",
    "Adding selection to folders" : "Lägger till urval i mappar",
    "Emptying trashbin" : "Tömmer papperskorgen",
    "Loading trashbin" : "Läser in papperskorgen",
    "Restoring folder" : "Återställer mapp",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Flyttar %n mapp och några bokmärken","Flyttar %n mappar och några bokmärken"],
    "_Moving %n folder_::_Moving %n folders_" : ["Flyttar %n mapp","Flyttar %n mappar"],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Flyttar %n bokmärke","Flyttar %n bokmärken"],
    "All bookmarks" : "Alla bokmärken",
    "Recent" : "Senaste",
    "Frequently clicked" : "Ofta klickade",
    "Shared with you" : "Delat med dig",
    "Files" : "Filer",
    "Duplicates" : "Dubbletter",
    "Broken links" : "Brutna länkar",
    "New tag" : "Ny tagg",
    "Search tags" : "Sök taggar",
    "Delete" : "Ta bort",
    "Untagged" : "Inte taggad",
    "{used} bookmarks of {available} available" : "{used} bokmärken av {available} tillgängliga",
    "Bookmarks Settings" : "Bokmärkesinställningar",
    "No bookmarked files" : "Inga bokmärkta filer",
    "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Bokmärken till filer som foton eller PDF-filer sparas automatiskt i ditt Nextcloud så att du fortfarande kan hitta dem även när länken går offline.",
    "Nothing found" : "Inget hittades",
    "Your search yielded no results in the current folder." : "Din sökning gav inga resultat i den nuvarande mappen.",
    "No broken links" : "Inga trasiga länkar",
    "No shared folders" : "Inga delade mappar",
    "No duplicated bookmarks" : "Inga bokmärkesdubbletter",
    "No deleted bookmarks" : "Inga borttagna bokmärken",
    "You haven't deleted anything yet." : "Du har inte tagit bort något ännu.",
    "No bookmarks here" : "Inga bokmärken här",
    "Add bookmarks manually or import bookmarks from a HTML file." : "Lägg till bokmärken manuellt eller importera bokmärken från en HTML-fil.",
    "Archive path" : "Sökväg till arkiv",
    "Backup path" : "Sökväg till säkerhetskopior",
    "Please select \"Add to home screen\" in your browser menu" : "Välj ”Lägg till på startskärmen” i webbläsarens meny",
    "Bookmarks settings" : "Bokmärkesinställningar",
    "Import/Export" : "Import och export",
    "Export bookmarks" : "Exportera bokmärken",
    "Auto-archiving" : "Automatisk arkivering",
    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Bokmärkesappen kan automatiskt arkivera webbinnehållet för länkar du har bokmärkt.",
    "Enable archiving" : "Aktivera arkivering",
    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Ange sökvägen till en mapp i dina filer där bokmärkta filer ska lagras.",
    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "För närvarande har din administratör inaktiverat nätverksåtkomst för den här appen, vilket är anledningen till att automatisk arkivering är inaktiverad för tillfället.",
    "Auto-Backup" : "Automatisk säkerhetskopiering",
    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Bokmärkesappen kan automatiskt säkerhetskopiera dina bokmärken dagligen för att förhindra dataförlust när du synkroniserar bokmärken mellan enheter.",
    "Enable backups" : "Aktivera säkerhetskopiering",
    "Enter the path of a folder in your Files where backups will be stored." : "Ange sökvägen till en mapp i dina filer där säkerhetskopior kommer att lagras.",
    "Context Chat integration" : "Integration med kontextchatt",
    "The bookmarks app can automatically make available the textual contents of the websites you bookmark to Context Chat, which allows asking questions about and getting answers based on those contents. This is only available if auto-archiving is enabled." : "Bokmärkesappen kan automatiskt göra textinnehållet på bokmärkta webbplatser tillgängligt för Context Chat, så att du kan ställa frågor och få svar utifrån innehållet. Funktionen är endast tillgänglig när automatisk arkivering är aktiverad.",
    "Context chat is currently not installed, but is required for this feature." : "Context Chat är inte installerat, men krävs för den här funktionen.",
    "Enable Context Chat integration" : "Aktivera integration med kontextchatt",
    "Client apps" : "Klientappar",
    "Also check out the collection of client apps that integrate with this app: " : "Se även samlingen med klientappar som integreras med den här appen: ",
    "Install web app" : "Installera webbapp",
    "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "Du kan installera appen på enhetens startskärm för att snabbt komma åt bokmärkena på telefonen. Appen kan enkelt tas bort från startskärmen igen.",
    "Install on home screen" : "Installera på hemskärmen",
    "Bookmarklet" : "Bookmarklet",
    "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Dra den här till webbläsarens bokmärken och klicka på den för att snabbt bokmärka en webbsida.",
    "Add to {instanceName}" : "Lägg till {instanceName}",
    "Need help?" : "Behöver du hjälp?",
    "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Om du har problem med denna bokmärkesapp eller har en idé om vad som kan förbättras, tveka inte att höra av dig genom att klicka här.",
    "Support this project" : "Stöd detta projekt",
    "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Mitt arbete med den här bokmärkesappen drivs av en frivillig prenumerationsmodell. Om du tycker att det jag gör är värt besväret skulle jag bli glad om du kunde stödja mitt arbete. Överväg också att ge appen en recension i Nextclouds appbutik. Tack 💙 ",
    "Created {time} ago" : "Skapad för {time} sedan",
    "Created on {date}" : "Skapad den {date}",
    "(Empty title)" : "(Tom titel)",
    "Title" : "Titel",
    "Link" : "Länk",
    "Untitled folder" : "Namnlös mapp",
    "Root folder" : "Rotmapp",
    "Tags" : "Taggar",
    "Select tags and create new ones" : "Välj taggar och skapa nya",
    "Notes" : "Anteckningar",
    "Notes for this bookmark …" : "Anteckningar för det här bokmärket …",
    "Archived file" : "Arkiverad fil",
    "Open file" : "Öppna fil",
    "Download file" : "Hämta fil",
    "Open file location" : "Öppna filens plats",
    "Link copied" : "Länken har kopierats",
    "Owner" : "Ägare",
    "Sharing" : "Delning",
    "Select a user or group" : "Välj en användare eller grupp",
    "Share link" : "Dela länk",
    "Reading allowed" : "Läsning tillåten",
    "Copy RSS feed" : "Kopiera RSS-flöde",
    "Delete link" : "Ta bort länk",
    "Create public link" : "Skapa offentlig länk",
    "Resharing allowed" : "Vidaredelning tillåten",
    "Editing allowed" : "Redigering tillåten",
    "Allow editing" : "Tillåt redigering",
    "Allow resharing" : "Tillåt vidaredelning",
    "Remove share" : "Ta bort delning",
    "Would you like to support this project?" : "Vill du stödja detta projekt?",
    "Leave a rating on the Nextcloud App Store" : "Lämna ett omdöme i Nextcloud-appbutiken",
    "Failed to save settings" : "Det gick inte att spara inställningarna",
    "Failed to load settings" : "Det gick inte att läsa in inställningarna",
    "Privacy" : "Integritet",
    "The app will try to access web pages that you add to automatically add information about them." : "Appen försöker komma åt webbsidor som du lägger till för att automatiskt hämta information om dem.",
    "Enable accessing and collecting information from the web pages you add" : "Tillåt åtkomst till och insamling av information från webbsidor som du lägger till",
    "Performance" : "Prestanda",
    "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "I en installation med många användare kan det vara nödvändigt att begränsa antalet bokmärken per konto.",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Maximalt tillåtet antal bokmärken per konto. (0 för ingen gräns; standard är ingen gräns)",
    "Previews" : "Förhandsvisningar",
    "In order to display real screenshots of your bookmarked websites, the app can use third-party services to generate previews." : "För att visa riktiga skärmdumpar av dina bokmärkta webbplatser kan appen använda tredjepartstjänster för att generera förhandsvisningar.",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Du kan antingen registrera dig gratis på screeenly.com eller sätta upp en egen server.",
    "Screeenly API URL" : "Screeenly API-webbadress",
    "Screeenly API key" : "Screeenly API-nyckel",
    "ScreenshotMachine" : "ScreenshotMachine",
    "ScreenshotMachine API key" : "ScreenshotMachine-API-nyckel",
    "Webshot" : "Webshot",
    "Webshot API URL" : "Webshot-API-webbadress",
    "Generic screenshot API" : "Generiskt API för skärmdumpar",
    "Sign up with any of the screenshot API providers and put the API URL below. Use the variable {url} as a placeholder for the URL to screenshot. The API must return only the image directly." : "Registrera dig hos någon av API-leverantörerna för skärmdumpar och ange API-webbadressen nedan. Använd variabeln {url} som platshållare för webbadressen som ska avbildas. API:t måste returnera endast själva bilden.",
    "Generic API URL" : "Generisk API-webbadress",
    "Pageres CLI" : "Pageres CLI",
    "Simply install the Pageres CLI by Sindre Sorhus on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "Installera Pageres CLI av Sindre Sorhus på din server så hittar Bokmärken det. Du kan fortfarande lägga till ytterligare ENV-variabler som ska matas till Pageres, t.ex. som anges i platshållaren:",
    "Pageres ENV variables" : "Pageres ENV-variabler",
    "This URL is already bookmarked! Overwrite?" : "Webbadressen är redan bokmärkt. Vill du skriva över bokmärket?",
    "Enter bookmark title" : "Ange titel",
    "Enter bookmark URL" : "Ange bokmärkets webbadress",
    "Folder" : "Mapp",
    "Root Folder" : "Rotmapp",
    "Save" : "Spara",
    "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "Nätverksåtkomst är inaktiverad som standard. Gå till administratörsinställningarna för Bokmärken för att tillåta hämtning av förhandsvisningar och webbplatsikoner.",
    "What's new?" : "Vad är nytt?",
    "What" : "Vad",
    "Failed to count unavailable bookmarks" : "Det gick inte att räkna otillgängliga bokmärken",
    "Failed to count archived bookmarks" : "Det gick inte att räkna arkiverade bokmärken",
    "Failed to count deleted bookmarks" : "Det gick inte att räkna borttagna bokmärken",
    "Failed to count duplicated bookmarks" : "Det gick inte att räkna dubblerade bokmärken",
    "Failed to count bookmarks" : "Det gick inte att räkna bokmärken",
    "Failed to load bookmark" : "Det gick inte att läsa in bokmärket",
    "Failed to find existing bookmark" : "Det gick inte att hitta ett befintligt bokmärke",
    "Failed to create bookmark" : "Det gick inte att skapa bokmärket",
    "Failed to save bookmark" : "Det gick inte att spara bokmärket",
    "Failed to move bookmark" : "Det gick inte att flytta bokmärket",
    "Failed to copy bookmark" : "Det gick inte att kopiera bokmärket",
    "Failed to delete bookmark" : "Det gick inte att ta bort bokmärket",
    "Failed to restore bookmark" : "Det gick inte att återställa bokmärket",
    "Import successful" : "Importen lyckades",
    "Failed to rename tag" : "Det gick inte att byta namn på taggen",
    "Failed to load tags" : "Det gick inte att läsa in taggarna",
    "Failed to load folders" : "Det gick inte att läsa in mapparna",
    "Failed to load deleted folders" : "Det gick inte att läsa in borttagna mappar",
    "Failed to load deleted bookmarks" : "Det gick inte att läsa in borttagna bokmärken",
    "Failed to delete folder" : "Det gick inte att ta bort mappen",
    "Failed to move folder" : "Det gick inte att flytta mappen",
    "Failed to restore folder" : "Det gick inte att återställa mappen",
    "Failed to create folder" : "Det gick inte att skapa mappen",
    "Failed to load children order" : "Det gick inte att läsa in ordningen för underordnade objekt",
    "Failed to move parts of selection" : "Det gick inte att flytta vissa delar av markeringen",
    "Failed to copy parts of selection" : "Det gick inte att kopiera vissa delar av markeringen",
    "Failed to delete parts of selection" : "Det gick inte att ta bort vissa delar av markeringen",
    "Failed to tag parts of selection" : "Det gick inte att tagga vissa delar av markeringen",
    "Failed to fetch bookmarks." : "Det gick inte att hämta bokmärken.",
    "Failed to store setting" : "Det gick inte att spara inställningen",
    "Failed to load setting {key}" : "Det gick inte att läsa in inställningen {key}",
    "Failed to create share for folder {folderId}" : "Det gick inte att skapa en delning för mappen {folderId}",
    "Failed to update share {shareId}" : "Det gick inte att uppdatera delningen {shareId}",
    "Failed to delete share {shareId}" : "Det gick inte att radera delningen {shareId}",
    "Failed to create public link for folder {folderId}" : "Det gick inte att skapa en offentlig länk för mappen {folderId}",
    "Failed to delete public link for folder {folderId}" : "Det gick inte att ta bort den offentliga länken för mappen {folderId}",
    "Failed to permanently delete parts of trash bin" : "Det gick inte att ta bort vissa delar av papperskorgen permanent",
    "Create bookmarks for mentioned links" : "Skapa bokmärken för nämnda länkar",
    "No links found in this message" : "Inga länkar hittades i detta meddelande",
    "Bookmarks feed" : "Bokmärkesflöde"
},
"nplurals=2; plural=(n != 1);");
